/*
 *******************************************************************************
 *
 *  Copyright 2025 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 */
/*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 * \version 2021-09-30/AW: Item "riegl.waveform_info" updated (schema+example, #4016)
 * \version 2021-10-04/AW: Improved spelling of the descriptions of some items
 * \version 2021-11-04/AW: Rename "riegl.record_names" to "riegl.item_names" (#4034)
 * \version 2022-03-11/AW: Item "riegl.devices" added (#4162)
 * \version 2022-03-14/AW: Item "riegl.stored_filters" added (#4164)
 * \version 2022-09-20/AW: Fix typos in schema of "riegl.georeferencing_parameters"
 * \version 2022-09-30/AW: Item "riegl.system_description" added (#4368)
 * \version 2022-10-10/AW: Correction of typos in the titles of some entries
 * \version 2022-10-20/AW: Item "riegl.stored_filters" updated (example, #4164)
 * \version 2023-01-19/AW: Item "riegl.ttip_configuration" added (#4449)
 * \version 2024-09-26/AW: Item "riegl.dyntrig" added (#5310)
 *
 *******************************************************************************
 */

#ifndef RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87
#define RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87

#include <vector>
#include <string>
#include <cstdlib>
#include <cstdint>

namespace riegl {
namespace rdb {
namespace pointcloud {

// Meta data item definition version
const std::string RDB_META_DATA_ITEMS_VERSION = "1.1.54";
const std::string RDB_META_DATA_ITEMS_DATE = "2023-01-19";

// Meta data item states
const unsigned char RDB_STATUS_REQUIRED = 1; // mandatory item
const unsigned char RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
struct MetaDataItemInfo
{
    std::string   name;
    std::string   title;
    std::string   description;
    unsigned char status;
    std::string   schema;
    std::string   example;

    operator const std::string&() const { return name; }
};

// Angular notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_ANGULAR_NOTCH_FILTER = {
    /* name        */ "riegl.angular_notch_filter",
    /* title       */ "Angular Notch Filter",
    /* description */ "Angular notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"angle\":{\"items\":{\"type\":\"number\"},\"description\":\"Angle"
    " [deg]\",\"type\":\"array\"},\"range_mean\":{\"items\":{\"type\":\"number\"},\"descr"
    "iption\":\"Mean range [m]\",\"type\":\"array\"},\"amplitude_mean\":{\"items\":{\"t"
    "ype\":\"number\"},\"description\":\"Mean amplitude [dB]\",\"type\":\"array\"}},\"r"
    "equired\":[\"angle\",\"range_mean\",\"amplitude_mean\"],\"description\":\"Angula"
    "r notch filter parameters for window glass echoes\",\"title\":\"Angular "
    "Notch Filter\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"typ"
    "e\":\"object\"}"
    ,
    /* example: */
    "{\"angle\":[14.0,15.0,16.0,17.0,18.0,19.0,20.0,21.0,22.0,23.0,24.0],\"ran"
    "ge_mean\":[0.094,0.094,0.09075,0.08675,0.0815,0.0775,0.074,0.071,0.068,"
    "0.0675,0.06475],\"amplitude_mean\":[3.780913,3.780913,3.480913,3.120913,"
    "2.850913,2.720913,2.680913,2.610913,2.530913,2.570913,2.570913]}"
};

// Atmospheric parameters
const MetaDataItemInfo RDB_RIEGL_ATMOSPHERE = {
    /* name        */ "riegl.atmosphere",
    /* title       */ "Atmosphere",
    /* description */ "Atmospheric parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"wavelength\":{\"description\":\"Laser wavelength "
    "[nm]\",\"type\":\"number\"},\"attenuation\":{\"description\":\"Atmospheric "
    "attenuation "
    "[1/km]\",\"type\":\"number\"},\"group_velocity\":{\"description\":\"Group "
    "velocity of laser beam "
    "[m/s]\",\"type\":\"number\"},\"temperature\":{\"description\":\"Temperature "
    "along measurement path "
    "[\\u00b0C]\",\"type\":\"number\"},\"pressure\":{\"description\":\"Pressure along "
    "measurment path [mbar]\",\"type\":\"number\"},\"amsl\":{\"description\":\"Height"
    " above mean sea level (AMSL) "
    "[m]\",\"type\":\"number\"},\"rel_humidity\":{\"description\":\"Relative humidity"
    " along measurement path "
    "[%]\",\"type\":\"number\"},\"pressure_sl\":{\"description\":\"Atmospheric "
    "pressure at sea level [mbar]\",\"type\":\"number\"}},\"required\":[\"temperatu"
    "re\",\"pressure\",\"rel_humidity\",\"pressure_sl\",\"amsl\",\"group_velocity\",\"a"
    "ttenuation\",\"wavelength\"],\"description\":\"Atmospheric "
    "parameters\",\"title\":\"Atmospheric Parameters\",\"$schema\":\"http://json-sc"
    "hema.org/draft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"wavelength\":1550,\"attenuation\":0.028125,\"group_velocity\":299711000.0"
    ",\"temperature\":7,\"pressure\":970,\"amsl\":0,\"rel_humidity\":63,\"pressure_s"
    "l\":970}"
};

// Laser beam geometry details
const MetaDataItemInfo RDB_RIEGL_BEAM_GEOMETRY = {
    /* name        */ "riegl.beam_geometry",
    /* title       */ "Beam Geometry",
    /* description */ "Laser beam geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"beam_exit_diameter\":{\"minimum\":0,\"type\":\"number\",\"excl"
    "usiveMinimum\":false,\"description\":\"Beam width at exit aperture [m]\"},\""
    "beam_divergence\":{\"minimum\":0,\"type\":\"number\",\"exclusiveMinimum\":false"
    ",\"description\":\"Beam divergence in far field [rad]\"}},\"required\":[\"bea"
    "m_exit_diameter\",\"beam_divergence\"],\"description\":\"Laser beam geometry"
    " details\",\"title\":\"Beam Geometry\",\"$schema\":\"http://json-schema.org/dr"
    "aft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"beam_exit_diameter\":0.0072,\"beam_divergence\":0.0003}"
};

// List of control object type definitions
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_CATALOG = {
    /* name        */ "riegl.control_object_catalog",
    /* title       */ "Control Object Catalog",
    /* description */ "List of control object type definitions",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"types\":{\"items\":{\"oneOf\":[{\"$ref\":\"#/definitions/recta"
    "ngle\"},{\"$ref\":\"#/definitions/checkerboard2x2\"},{\"$ref\":\"#/definitions"
    "/chevron\"},{\"$ref\":\"#/definitions/circular_disk\"},{\"$ref\":\"#/definitio"
    "ns/cylinder\"},{\"$ref\":\"#/definitions/sphere\"},{\"$ref\":\"#/definitions/r"
    "ound_corner_cube_prism\"}],\"type\":\"object\"},\"uniqueItems\":true,\"type\":\""
    "array\"}},\"required\":[\"types\"],\"definitions\":{\"rectangle\":{\"allOf\":[{\"$"
    "ref\":\"#/definitions/common\"},{\"properties\":{\"length\":{\"minimum\":0,\"typ"
    "e\":\"number\",\"exclusiveMinimum\":true,\"description\":\"length in meters\"},"
    "\"shape\":{\"enum\":[\"rectangle\"],\"type\":\"string\"},\"width\":{\"minimum\":0,\"t"
    "ype\":\"number\",\"exclusiveMinimum\":true,\"description\":\"width in meters\"}"
    "},\"type\":\"object\",\"required\":[\"shape\",\"length\",\"width\"],\"description\":"
    "\"rectangle specific properties\"}],\"type\":\"object\",\"description\":\"recta"
    "ngle\"},\"checkerboard2x2\":{\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"p"
    "roperties\":{\"square_length\":{\"minimum\":0,\"type\":\"number\",\"exclusiveMin"
    "imum\":true,\"description\":\"length of a square of the checkerboard in me"
    "ters\"},\"shape\":{\"type\":\"string\",\"enum\":[\"checkerboard2x2\"],\"descriptio"
    "n\":\"shape identifier\"}},\"type\":\"object\",\"required\":[\"shape\",\"square_le"
    "ngth\"],\"description\":\"checkerboard specific "
    "properties\"}],\"type\":\"object\",\"description\":\"checkerboard 2 by 2\"},\"ci"
    "rcular_disk\":{\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"properties\":{"
    "\"offset\":{\"type\":\"number\",\"description\":\"offset in meters, e.g. "
    "reflector constant (optional)\"},\"diameter\":{\"minimum\":0,\"type\":\"number"
    "\",\"exclusiveMinimum\":true,\"description\":\"diameter in meters\"},\"shape\":"
    "{\"type\":\"string\",\"enum\":[\"circular_disk\"],\"description\":\"shape identif"
    "ier\"}},\"type\":\"object\",\"required\":[\"shape\",\"diameter\"],\"description\":\""
    "circular disk specific "
    "properties\"}],\"type\":\"object\",\"description\":\"circular disk\"},\"chevron\""
    ":{\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"properties\":{\"shape\":{\"ty"
    "pe\":\"string\",\"enum\":[\"chevron\"],\"description\":\"shape identifier\"},\"thi"
    "ckness\":{\"minimum\":0,\"type\":\"number\",\"exclusiveMinimum\":true,\"descript"
    "ion\":\"thickness in meters\"},\"outside_edge_length\":{\"minimum\":0,\"type\":"
    "\"number\",\"exclusiveMinimum\":true,\"description\":\"length of the two "
    "outer edges in meters\"}},\"type\":\"object\",\"required\":[\"shape\",\"outside_"
    "edge_length\",\"thickness\"],\"description\":\"chevron specific properties\"}"
    "],\"type\":\"object\",\"description\":\"chevron\"},\"cylinder\":{\"allOf\":[{\"$ref"
    "\":\"#/definitions/common\"},{\"properties\":{\"diameter\":{\"minimum\":0,\"type"
    "\":\"number\",\"exclusiveMinimum\":true,\"description\":\"diameter in meters\"}"
    ",\"height\":{\"minimum\":0,\"type\":\"number\",\"exclusiveMinimum\":true,\"descri"
    "ption\":\"height in meters\"},\"shape\":{\"type\":\"string\",\"enum\":[\"cylinder\""
    "],\"description\":\"shape identifier\"}},\"type\":\"object\",\"required\":[\"shap"
    "e\",\"diameter\",\"height\"],\"description\":\"cylinder specific properties\"}]"
    ",\"type\":\"object\",\"description\":\"cylinder\"},\"common\":{\"properties\":{\"su"
    "rface_type\":{\"type\":\"string\",\"enum\":[\"retro_reflective_foil\",\"diffuse\""
    "],\"description\":\"surface material "
    "type\"},\"name\":{\"type\":\"string\",\"minLength\":3,\"description\":\"unique "
    "type identifier\"},\"shape\":{\"type\":\"string\",\"enum\":[\"rectangle\",\"checke"
    "rboard2x2\",\"chevron\",\"circular_disk\",\"cylinder\",\"sphere\",\"round_corner"
    "_cube_prism\"],\"description\":\"shape "
    "identifier\"},\"description\":{\"type\":\"string\",\"description\":\"string "
    "describing the object\"}},\"type\":\"object\",\"required\":[\"name\",\"shape\"],\""
    "description\":\"common object properties\"},\"round_corner_cube_prism\":{\"a"
    "llOf\":[{\"$ref\":\"#/definitions/common\"},{\"properties\":{\"offset\":{\"type\""
    ":\"number\",\"description\":\"offset in meters, e.g. reflector constant (op"
    "tional)\"},\"diameter\":{\"minimum\":0,\"type\":\"number\",\"exclusiveMinimum\":t"
    "rue,\"description\":\"diameter in meters\"},\"shape\":{\"type\":\"string\",\"enum"
    "\":[\"round_corner_cube_prism\"],\"description\":\"shape identifier\"}},\"type"
    "\":\"object\",\"required\":[\"shape\",\"diameter\"],\"description\":\"round corner"
    " cube prism specific "
    "properties\"}],\"type\":\"object\",\"description\":\"round corner cube prism\"}"
    ",\"sphere\":{\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"properties\":{\"di"
    "ameter\":{\"minimum\":0,\"type\":\"number\",\"exclusiveMinimum\":true,\"descript"
    "ion\":\"diameter in meters\"},\"shape\":{\"type\":\"string\",\"enum\":[\"sphere\"],"
    "\"description\":\"shape identifier\"}},\"type\":\"object\",\"required\":[\"shape\""
    ",\"diameter\"],\"description\":\"sphere specific properties\"}],\"type\":\"obje"
    "ct\",\"description\":\"sphere\"}},\"description\":\"List of control object "
    "type definitions\",\"title\":\"Control Object Catalog\",\"$schema\":\"http://j"
    "son-schema.org/draft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"comments\":[\"This file contains a list of control object types (aka. "
    "'catalog').\",\"Each type is described by an object,\",\"which must "
    "contain at least the following parameters:\",\"  - name: unique "
    "identifier of the type\",\"  - shape: one of the following supported "
    "shapes:\",\"      - rectangle\",\"      - checkerboard2x2\",\"      - "
    "chevron\",\"      - circular_disk\",\"      - cylinder\",\"      - sphere\",\""
    "      - round_corner_cube_prism\",\"Depending on 'shape', the following "
    "parameters must/may be specified:\",\"  - rectangle:\",\"      - length: "
    "length in meters\",\"      - width: width in meters\",\"  - "
    "checkerboard2x2:\",\"      - square_length: length of a square of the "
    "checkerboard in meters\",\"  - circular_disk:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"  - chevron:\",\"      - outside_edge_length: "
    "length of the two outer edges in meters\",\"      - thickness: thickness"
    " in meters\",\"  - cylinder:\",\"      - diameter: diameter in meters\",\""
    "      - height: height in meters\",\"  - sphere:\",\"      - diameter: "
    "diameter in meters\",\"  - round_corner_cube_prism:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"Optional parameters:\",\"    - description: string"
    " describing the object\",\"    - surface_type: surface material type "
    "(either 'retro_reflective_foil' or "
    "'diffuse')\"],\"types\":[{\"name\":\"Rectangle 60x30\",\"shape\":\"rectangle\",\"l"
    "ength\":0.6,\"width\":0.3,\"description\":\"Rectangle (60cm x "
    "30cm)\"},{\"name\":\"Rectangle 80x40\",\"shape\":\"rectangle\",\"length\":0.8,\"wi"
    "dth\":0.4,\"description\":\"Rectangle (80cm x "
    "40cm)\"},{\"name\":\"Checkerboard2x2 30\",\"shape\":\"checkerboard2x2\",\"square"
    "_length\":0.3,\"description\":\"Checkerboard (square length: "
    "30cm)\"},{\"name\":\"Checkerboard2x2 50\",\"shape\":\"checkerboard2x2\",\"square"
    "_length\":0.5,\"description\":\"Checkerboard (square length: "
    "50cm)\"},{\"name\":\"Chevron 24''/4''\",\"shape\":\"chevron\",\"outside_edge_len"
    "gth\":0.6096,\"thickness\":0.1016,\"description\":\"Chevron (a=24''; "
    "b=4'')\"},{\"surface_type\":\"diffuse\",\"diameter\":0.5,\"name\":\"Circular "
    "Disk 50\",\"shape\":\"circular_disk\",\"description\":\" Circular Disk "
    "(diameter: "
    "50cm)\"},{\"surface_type\":\"retro_reflective_foil\",\"name\":\"RIEGL flat "
    "reflector 50 mm\",\"shape\":\"circular_disk\",\"description\":\"flat circular "
    "reflector from retro-reflective foil\",\"offset\":0.0,\"diameter\":0.05},{\""
    "surface_type\":\"retro_reflective_foil\",\"name\":\"RIEGL flat reflector 100"
    " mm\",\"shape\":\"circular_disk\",\"description\":\"flat circular reflector "
    "from retro-reflective foil\",\"offset\":0.0,\"diameter\":0.1},{\"surface_typ"
    "e\":\"retro_reflective_foil\",\"name\":\"RIEGL flat reflector 150 "
    "mm\",\"shape\":\"circular_disk\",\"description\":\"flat circular reflector "
    "from retro-reflective "
    "foil\",\"offset\":0.0,\"diameter\":0.15},{\"name\":\"RIEGL cylindrical "
    "reflector 50 mm\",\"shape\":\"cylinder\",\"description\":\"cylindrical "
    "reflector from retro-reflective foil\",\"surface_type\":\"retro_reflective"
    "_foil\",\"height\":0.05,\"diameter\":0.05},{\"name\":\"RIEGL cylindrical "
    "reflector 100 mm\",\"shape\":\"cylinder\",\"description\":\"cylindrical "
    "reflector from retro-reflective foil\",\"surface_type\":\"retro_reflective"
    "_foil\",\"height\":0.1,\"diameter\":0.1},{\"diameter\":0.2,\"name\":\"Sphere 200"
    " mm\",\"shape\":\"sphere\",\"description\":\"Sphere (diameter: 200 "
    "mm)\"},{\"offset\":0.0,\"diameter\":0.05,\"name\":\"Corner Cube Prism 50 "
    "mm\",\"shape\":\"round_corner_cube_prism\",\"description\":\"round corner cube"
    " prism\"}]}"
};

// Details about the control object reference file
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE = {
    /* name        */ "riegl.control_object_reference_file",
    /* title       */ "Control Object Reference file",
    /* description */ "Details about the control object reference file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Control Object Reference "
    "file\",\"description\":\"Details about the control object reference file\","
    "\"properties\":{\"reference_file\":{\"properties\":{\"file_uuid\":{\"type\":\"str"
    "ing\",\"description\":\"Control object file's Universally Unique "
    "Identifier (RFC "
    "4122)\"},\"file_path\":{\"type\":\"string\",\"description\":\"Path of the "
    "control object file relative to referring "
    "file\"}},\"description\":\"Reference to a control object file\",\"required\":"
    "[\"file_uuid\",\"file_path\"],\"type\":\"object\"}},\"$schema\":\"http://json-sch"
    "ema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"reference_file\":{\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b4213\","
    "\"file_path\":\"../../../10_CONTROL_OBJECTS/ControlPoints.cpx\"}}"
};

// Detection probability as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_DETECTION_PROBABILITY = {
    /* name        */ "riegl.detection_probability",
    /* title       */ "Detection Probability",
    /* description */ "Detection probability as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"amplitude\":{\"items\":{\"type\":\"number\"},\"description\":\"A"
    "mplitude [dB]\",\"type\":\"array\"},\"detection_probability\":{\"items\":{\"type"
    "\":\"number\"},\"description\":\"Detection probability [0..1]\",\"type\":\"array"
    "\"}},\"required\":[\"amplitude\",\"detection_probability\"],\"description\":\"De"
    "tection probability as a function of amplitude\",\"title\":\"Detection Pro"
    "bability\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\""
    "object\"}"
    ,
    /* example: */
    "{\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0],\"detection"
    "_probability\":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]}"
};

// Details about the device used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICE = {
    /* name        */ "riegl.device",
    /* title       */ "Device Information",
    /* description */ "Details about the device used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"channel_number\":{\"minimum\":0,\"type\":\"integer\",\"exclusi"
    "veMinimum\":false,\"description\":\"Laser channel number (not defined or "
    "0: single channel "
    "device)\"},\"channel_text\":{\"type\":\"string\",\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel "
    "devices)\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device build"
    " variant\"},\"device_type\":{\"type\":\"string\",\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\"},\"device_name\":{\"type\":\"string\",\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\"},\"serial_number\":{\"type\":\"string\",\"description\":\"Device "
    "serial number (e.g. S2221234)\"}},\"required\":[\"device_type\",\"serial_num"
    "ber\"],\"description\":\"Details about the device used to acquire the "
    "point cloud\",\"title\":\"Device Information\",\"$schema\":\"http://json-schem"
    "a.org/draft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"channel_number\":0,\"channel_text\":\"\",\"device_build\":\"\",\"device_type\":"
    "\"VZ-400i\",\"device_name\":\"Scanner 1\",\"serial_number\":\"S2221234\"}"
};

// Scanner device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY = {
    /* name        */ "riegl.device_geometry",
    /* title       */ "Device Geometry",
    /* description */ "Scanner device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"secondary\":{\"properties\":{\"content\":{\"items\":{\"type\":\""
    "number\"},\"type\":\"array\",\"description\":\"Internal calibration values\"},\""
    "ID\":{\"items\":{\"type\":\"integer\"},\"minItems\":2,\"type\":\"array\",\"maxItems\""
    ":2,\"description\":\"Structure identifier\"}},\"type\":\"object\",\"required\":["
    "\"ID\",\"content\"],\"description\":\"Additional device geometry structure (o"
    "ptional)\"},\"amu\":{\"properties\":{\"lineCC\":{\"minimum\":0,\"type\":\"number\","
    "\"exclusiveMinimum\":false,\"description\":\"Line Circle Count (number of "
    "LSBs per full rotation about line axis)\"},\"frameCC\":{\"minimum\":0,\"type"
    "\":\"number\",\"exclusiveMinimum\":false,\"description\":\"Frame Circle Count "
    "(number of LSBs per full rotation about frame "
    "axis)\"}},\"type\":\"object\",\"description\":\"Angle Measurement Unit\"},\"prim"
    "ary\":{\"properties\":{\"content\":{\"items\":{\"type\":\"number\"},\"type\":\"array"
    "\",\"description\":\"Internal calibration values\"},\"ID\":{\"items\":{\"type\":\""
    "integer\"},\"minItems\":2,\"type\":\"array\",\"maxItems\":2,\"description\":\"Stru"
    "cture identifier\"}},\"type\":\"object\",\"required\":[\"ID\",\"content\"],\"descr"
    "iption\":\"Primary device geometry structure "
    "(mandatory)\"}},\"required\":[\"primary\"],\"description\":\"Scanner device "
    "geometry details\",\"title\":\"Device Geometry\",\"$schema\":\"http://json-sch"
    "ema.org/draft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"secondary\":{\"content\":[0],\"ID\":[91,0]},\"amu\":{\"lineCC\":124000,\"frame"
    "CC\":124000},\"primary\":{\"content\":[0],\"ID\":[4,0]}}"
};

// Scanner passive channel device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL = {
    /* name        */ "riegl.device_geometry_passive_channel",
    /* title       */ "Device Geometry Passive Channel",
    /* description */ "Scanner passive channel device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"primary\":{\"properties\":{\"content\":{\"items\":{\"type\":\"nu"
    "mber\"},\"type\":\"array\",\"description\":\"Internal calibration values\"},\"ID"
    "\":{\"items\":{\"type\":\"integer\"},\"minItems\":2,\"type\":\"array\",\"maxItems\":2"
    ",\"description\":\"Structure identifier\"}},\"type\":\"object\",\"required\":[\"I"
    "D\",\"content\"],\"description\":\"Primary device geometry structure "
    "(mandatory)\"}},\"required\":[\"primary\"],\"description\":\"Scanner passive "
    "channel device geometry details\",\"title\":\"Device Geometry Passive Chan"
    "nel\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"objec"
    "t\"}"
    ,
    /* example: */
    "{\"primary\":{\"content\":[0],\"ID\":[143,0]}}"
};

// Limits of the measured values output by the device
const MetaDataItemInfo RDB_RIEGL_DEVICE_OUTPUT_LIMITS = {
    /* name        */ "riegl.device_output_limits",
    /* title       */ "Device Output Limits",
    /* description */ "Limits of the measured values output by the device",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Device Output Limits\",\"description\":\"Limits "
    "of the measured values output by the device. The limits depend on the "
    "device type, measurement program and/or scan "
    "pattern.\",\"properties\":{\"echo_count_maximum\":{\"description\":\"Maximum "
    "number of echoes a laser shot can "
    "have.\",\"type\":\"number\"},\"amplitude_minimum\":{\"description\":\"Minimum "
    "possible amplitude in "
    "dB.\",\"type\":\"number\"},\"reflectance_minimum\":{\"description\":\"Minimum "
    "possible reflectance in "
    "dB.\",\"type\":\"number\"},\"mta_zone_count_maximum\":{\"description\":\"Maximum"
    " number of MTA "
    "zones.\",\"type\":\"number\"},\"deviation_minimum\":{\"description\":\"Minimum "
    "possible pulse shape "
    "deviation.\",\"type\":\"number\"},\"range_minimum\":{\"description\":\"Minimum "
    "possible range in "
    "meters.\",\"type\":\"number\"},\"range_maximum\":{\"description\":\"Maximum "
    "possible range in meters.\",\"type\":\"number\"},\"background_radiation_mini"
    "mum\":{\"description\":\"Minimum possible background radiation.\",\"type\":\"n"
    "umber\"},\"amplitude_maximum\":{\"description\":\"Maximum possible amplitude"
    " in "
    "dB.\",\"type\":\"number\"},\"reflectance_maximum\":{\"description\":\"Maximum "
    "possible reflectance in dB.\",\"type\":\"number\"},\"background_radiation_ma"
    "ximum\":{\"description\":\"Maximum possible background radiation.\",\"type\":"
    "\"number\"},\"deviation_maximum\":{\"description\":\"Maximum possible pulse "
    "shape deviation.\",\"type\":\"number\"}},\"$schema\":\"http://json-schema.org/"
    "draft-04/schema#\"}"
    ,
    /* example: */
    "{\"background_radiation_maximum\":0,\"amplitude_minimum\":0.0,\"reflectance"
    "_minimum\":-100.0,\"range_maximum\":10000.0,\"deviation_maximum\":32767,\"am"
    "plitude_maximum\":100.0,\"reflectance_maximum\":100.0,\"background_radiati"
    "on_minimum\":0,\"mta_zone_count_maximum\":7,\"deviation_minimum\":-1,\"range"
    "_minimum\":2.9}"
};

// Details about the devices used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICES = {
    /* name        */ "riegl.devices",
    /* title       */ "Devices Information",
    /* description */ "Details about the devices used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"array\",\"items\":{\"properties\":{\"signed\":{\"type\":\"boolean\",\"des"
    "cription\":\"Flag that is set when the original 'riegl.device' entry in "
    "the source file was correctly signed.\"},\"channel_number\":{\"minimum\":0,"
    "\"type\":\"integer\",\"exclusiveMinimum\":false,\"description\":\"Laser channel"
    " number (not defined or 0: single channel "
    "device)\"},\"channel_text\":{\"type\":\"string\",\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel "
    "devices)\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device build"
    " variant\"},\"device_type\":{\"type\":\"string\",\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\"},\"device_name\":{\"type\":\"string\",\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\"},\"serial_number\":{\"type\":\"string\",\"description\":\"Device "
    "serial number (e.g. S2221234)\"}},\"required\":[\"device_type\",\"serial_num"
    "ber\"],\"type\":\"object\"},\"title\":\"Devices "
    "Information\",\"description\":\"Details about the devices used to acquire "
    "the point cloud (e.g. when merging point clouds of different "
    "devices)\",\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "[{\"signed\":false,\"channel_number\":0,\"channel_text\":\"\",\"device_build\":\""
    "\",\"device_type\":\"VZ-400i\",\"device_name\":\"Scanner 1\",\"serial_number\":\"S"
    "2221234\"},{\"signed\":true,\"channel_number\":1,\"channel_text\":\"\",\"device_"
    "build\":\"\",\"device_type\":\"VQ-1560i-DW\",\"device_name\":\"Scanner 2\",\"seria"
    "l_number\":\"S2222680\"},{\"signed\":true,\"channel_number\":2,\"channel_text\""
    ":\"\",\"device_build\":\"\",\"device_type\":\"VQ-1560i-DW\",\"device_name\":\"Scann"
    "er 3\",\"serial_number\":\"S2222680\"}]"
};

// Dyntrig
const MetaDataItemInfo RDB_RIEGL_DYNTRIG = {
    /* name        */ "riegl.dyntrig",
    /* title       */ "Dyntrig",
    /* description */ "Dyntrig",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Dyntrig\",\"description\":\"Dyntrig\",\"properties\":{\"offset\":{\"de"
    "scription\":\"Offset in units of dB, for calculation of line\",\"type\":\"nu"
    "mber\"},\"tab\":{\"items\":{\"properties\":{\"del1\":{\"type\":\"number\",\"descript"
    "ion\":\"Length of constant post-trigger threshold elevation in units of "
    "m\"},\"thra1\":{\"type\":\"number\",\"description\":\"Post-trigger threshold in "
    "units of dB\"},\"thra2\":{\"type\":\"number\",\"description\":\"Pre-trigger "
    "threshold in units of "
    "dB\"},\"dec1\":{\"type\":\"number\",\"description\":\"Decay of post-trigger "
    "threshold after del1 in units of "
    "dB/m\"},\"dec2\":{\"type\":\"number\",\"description\":\"Rise of pre-trigger "
    "threshold after del2 in units of "
    "dB/m\"},\"del2\":{\"type\":\"number\",\"description\":\"Length of constant "
    "pre-trigger threshold elevation in units of m\"}},\"type\":\"object\",\"requ"
    "ired\":[\"thra1\",\"del1\",\"dec1\",\"thra2\",\"del2\",\"dec2\"],\"description\":\"..."
    "\"},\"minItems\":1,\"maxItems\":128,\"description\":\"...\",\"type\":\"array\"},\"sc"
    "ale\":{\"description\":\"Scale in units of dB, for calculation of line: "
    "line number N=(amplitude-offset)/scale\",\"type\":\"number\"},\"pre\":{\"prope"
    "rties\":{\"a\":{\"items\":{\"type\":\"number\"},\"minItems\":1,\"maxItems\":2080,\"d"
    "escription\":\"...\",\"type\":\"array\"},\"nc\":{\"minimum\":0,\"description\":\"Num"
    "ber of "
    "entries\",\"maximum\":255,\"type\":\"integer\"}},\"description\":\"Dyntrig pre v"
    "alues\",\"required\":[\"nc\",\"a\"],\"type\":\"object\"},\"post\":{\"properties\":{\"a"
    "\":{\"items\":{\"type\":\"number\"},\"minItems\":1,\"maxItems\":2080,\"description"
    "\":\"...\",\"type\":\"array\"},\"nc\":{\"minimum\":0,\"description\":\"Number of "
    "entries\",\"maximum\":255,\"type\":\"integer\"}},\"description\":\"Dyntrig post "
    "values\",\"required\":[\"nc\",\"a\"],\"type\":\"object\"}},\"$schema\":\"http://json"
    "-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"offset\":0.0,\"tab\":[{\"del1\":0.0,\"thra1\":0.0,\"thra2\":0.0,\"dec1\":0.0,\"d"
    "ec2\":0.0,\"del2\":0.0}],\"scale\":1.0,\"pre\":{\"a\":[78,86,126,134,31],\"nc\":1"
    "28},\"post\":{\"a\":[78,86,126,134,31],\"nc\":128}}"
};

// Details about echo files
const MetaDataItemInfo RDB_RIEGL_ECHO_INFO = {
    /* name        */ "riegl.echo_info",
    /* title       */ "Echo Information",
    /* description */ "Details about echo files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"echo_file\":{\"properties\":{\"file_extension\":{\"type\":\"st"
    "ring\",\"description\":\"Echo file extension, without the leading "
    "dot\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC 4122)\"}},\"required\":[\"file_extension\"],\"type\":\""
    "object\"}},\"required\":[\"echo_file\"],\"description\":\"Details about echo "
    "files\",\"title\":\"Echo Information\",\"$schema\":\"http://json-schema.org/dr"
    "aft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"echo_file\":{\"file_extension\":\"owp\",\"file_uuid\":\"26a03615-67c0-4bea-8"
    "fe8-c577378fe661\"}}"
};

// Details for exponential decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_EXPONENTIAL_DECOMPOSITION = {
    /* name        */ "riegl.exponential_decomposition",
    /* title       */ "Exponential Decomposition",
    /* description */ "Details for exponential decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"additionalProperties\":false,\"definitions\":{\"channel\":{\"properties\":{"
    "\"scale\":{\"type\":\"number\",\"description\":\"amplitude calibration\"},\"a_lin"
    "\":{\"exclusiveMinimum\":false,\"description\":\"relative linear amplitude "
    "range [0..1]\",\"exclusiveMaximum\":false,\"minimum\":0,\"maximum\":1,\"type\":"
    "\"number\"},\"delay\":{\"type\":\"number\",\"description\":\"delay calibration in"
    " seconds\"},\"parameter\":{\"properties\":{\"A\":{\"items\":{\"type\":\"number\"},\""
    "type\":\"array\",\"description\":\"real part of amplitude factor in units of"
    " full-scale\"},\"gamma\":{\"items\":{\"type\":\"number\"},\"type\":\"array\",\"descr"
    "iption\":\"decay in 1/second\"},\"omega\":{\"items\":{\"type\":\"number\"},\"type\""
    ":\"array\",\"description\":\"angular frequency in Hz\"},\"B\":{\"items\":{\"type\""
    ":\"number\"},\"type\":\"array\",\"description\":\"imaginary part of amplitude "
    "factor in units of full-scale\"}},\"type\":\"object\",\"required\":[\"A\",\"B\",\""
    "gamma\",\"omega\"],\"description\":\"parameters of the syswave exponential s"
    "um\"}},\"required\":[\"delay\",\"scale\",\"parameter\"],\"type\":\"object\"}},\"desc"
    "ription\":\"Details for exponential decomposition of full waveform "
    "data\",\"title\":\"Exponential Decomposition\",\"$schema\":\"http://json-schem"
    "a.org/draft-04/schema#\",\"patternProperties\":{\"^[0-9]+$\":{\"$ref\":\"#/def"
    "initions/channel\",\"description\":\"one field per channel, field name is "
    "channel index\"}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"0\":{\"scale\":1.0,\"a_lin\":0.27,\"delay\":3.783458418887631e-09,\"paramete"
    "r\":{\"A\":[0.9772450923919678,0.3354335129261017,-1.312678575515747],\"ga"
    "mma\":[-1094726528.0,-769562752.0,-848000064.0],\"omega\":[352020896.0,36"
    "47927552.0,-1977987072.0],\"B\":[-3.9813032150268555,0.08622030913829803"
    ",-0.3152860999107361]}},\"1\":{\"scale\":1.0,\"a_lin\":0.9,\"delay\":3.5e-09,\""
    "parameter\":{\"A\":[0.9,0.3,-1.3],\"gamma\":[-1094726528.0,-769562752.0,-84"
    "8000064.0],\"omega\":[352020896.0,3647927552.0,-1977987072.0],\"B\":[-3.9,"
    "0.0,-0.3]}}}"
};

// Details for Gaussian decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_GAUSSIAN_DECOMPOSITION = {
    /* name        */ "riegl.gaussian_decomposition",
    /* title       */ "Gaussian Decomposition",
    /* description */ "Details for Gaussian decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"amplitude_lsb_high_power\":{\"items\":{\"type\":\"number\"},\""
    "type\":\"array\"},\"range_offset_sec_high_power\":{\"items\":{\"type\":\"number\""
    "},\"type\":\"array\"},\"amplitude_lsb_low_power\":{\"items\":{\"type\":\"number\"}"
    ",\"type\":\"array\"},\"range_offset_sec_low_power\":{\"items\":{\"type\":\"number"
    "\"},\"type\":\"array\"},\"amplitude_db\":{\"items\":{\"type\":\"number\"},\"type\":\"a"
    "rray\"}},\"required\":[\"amplitude_lsb_low_power\",\"amplitude_lsb_high_powe"
    "r\",\"amplitude_db\",\"range_offset_sec_low_power\",\"range_offset_sec_high_"
    "power\"],\"description\":\"riegl.gaussian_decomposition contains "
    "information relevant for extracting calibrated amplitudes and "
    "calibrated ranges from a Gaussian decomposition of full waveform data."
    " This information is contained in a table with five columns. Two "
    "columns are to be used as input: amplitude_lsb_low_power and "
    "amplitude_lsb_high_power. The other three columns provide the outputs."
    " Amplitude_db gives the calibrated amplitude in the optical regime in "
    "decibels. The range offset columns provide additive range offsets, "
    "given in units of seconds, for each channel.\",\"title\":\"Gaussian Decomp"
    "osition\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"o"
    "bject\"}"
    ,
    /* example: */
    "{\"amplitude_lsb_high_power\":[],\"range_offset_sec_high_power\":[],\"ampli"
    "tude_lsb_low_power\":[],\"range_offset_sec_low_power\":[],\"amplitude_db\":"
    "[]}"
};

// Point cloud georeferencing information
const MetaDataItemInfo RDB_RIEGL_GEO_TAG = {
    /* name        */ "riegl.geo_tag",
    /* title       */ "Geo Tag",
    /* description */ "Point cloud georeferencing information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Geo Tag\",\"description\":\"Point cloud "
    "georeferencing information\",\"properties\":{\"crs\":{\"properties\":{\"wkt\":{"
    "\"type\":\"string\",\"description\":\"\\\"Well-Known Text\\\" string, OGC WKT "
    "dialect (see http://www.opengeospatial.org/standards/wkt-crs)\"},\"name\""
    ":{\"type\":\"string\",\"description\":\"Coordinate reference system "
    "name\"},\"epsg\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"EPSG "
    "code\"}},\"description\":\"Global Coordinate Reference System. Please note"
    " that only 3D Cartesian Coordinate Systems are allowed.\",\"type\":\"objec"
    "t\"},\"pose\":{\"items\":{\"items\":{\"type\":\"number\",\"description\":\"columns\"}"
    ",\"maxItems\":4,\"type\":\"array\",\"minItems\":4,\"description\":\"rows\"},\"maxIt"
    "ems\":4,\"description\":\"Coordinate Transformation Matrix to transform "
    "from File Coordinate System to Global Coordinate Reference System. 4x4"
    " matrix stored as two dimensional array, row major order.\",\"minItems\":"
    "4,\"type\":\"array\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\""
    "}"
    ,
    /* example: */
    "{\"crs\":{\"wkt\":\"GEOCCS[\\\"WGS84 Geocentric\\\",DATUM[\\\"WGS84\\\",SPHEROID[\\\""
    "WGS84\\\",6378137.000,298.257223563,AUTHORITY[\\\"EPSG\\\",\\\"7030\\\"]],AUTHOR"
    "ITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.0000000000000000,AUTHOR"
    "ITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Meter\\\",1.00000000000000000000,AUTHORIT"
    "Y[\\\"EPSG\\\",\\\"9001\\\"]],AXIS[\\\"X\\\",OTHER],AXIS[\\\"Y\\\",EAST],AXIS[\\\"Z\\\",NO"
    "RTH],AUTHORITY[\\\"EPSG\\\",\\\"4978\\\"]]\",\"name\":\"WGS84 Geocentric\",\"epsg\":4"
    "978},\"pose\":[[-0.269827776749716,-0.723017716139738,0.635954678449952,"
    "4063882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847"
    ",1138787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196"
    "],[0.0,0.0,0.0,1.0]]}"
};

// Geometric scale factor applied to point coordinates
const MetaDataItemInfo RDB_RIEGL_GEOMETRIC_SCALE_FACTOR = {
    /* name        */ "riegl.geometric_scale_factor",
    /* title       */ "Geometric Scale Factor",
    /* description */ "Geometric scale factor applied to point coordinates",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"number\",\"exclusiveMinimum\":true,\"description\":\"Geometric "
    "scale factor applied to point coordinates\",\"minimum\":0,\"$schema\":\"http"
    "://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "1.0"
};

// Parameters used for georeferencing of the point cloud
const MetaDataItemInfo RDB_RIEGL_GEOREFERENCING_PARAMETERS = {
    /* name        */ "riegl.georeferencing_parameters",
    /* title       */ "Georeferencing Parameters",
    /* description */ "Parameters used for georeferencing of the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Georeferencing "
    "Parameters\",\"description\":\"Parameters used for georeferencing of the "
    "point cloud\",\"properties\":{\"socs_to_body_matrix\":{\"items\":{\"items\":{\"t"
    "ype\":\"number\",\"description\":\"columns\"},\"maxItems\":4,\"type\":\"array\",\"mi"
    "nItems\":4,\"description\":\"rows\"},\"maxItems\":4,\"description\":\"Coordinate"
    " Transformation Matrix to transform from Scanner's Own Coordinate "
    "System to Body Coordinate System. 4x4 matrix stored as two dimensional"
    " array, row major order.\",\"minItems\":4,\"type\":\"array\"},\"trajectory_off"
    "sets\":{\"properties\":{\"offset_height\":{\"description\":\"[m]\",\"type\":\"numb"
    "er\"},\"offset_north\":{\"description\":\"[m]\",\"type\":\"number\"},\"version\":{\""
    "description\":\"Meaning of offset values and how to apply them; version "
    "0: Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), "
    "version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(offset_yaw)*Ry(offset_pitch"
    ")*Rx(offset_roll)\",\"type\":\"integer\"},\"offset_roll\":{\"description\":\"[de"
    "g]\",\"type\":\"number\"},\"offset_pitch\":{\"description\":\"[deg]\",\"type\":\"num"
    "ber\"},\"offset_east\":{\"description\":\"[m]\",\"type\":\"number\"},\"offset_time"
    "\":{\"description\":\"[s]\",\"type\":\"number\"},\"offset_yaw\":{\"description\":\"["
    "deg]\",\"type\":\"number\"}},\"description\":\"Correction offsets applied to "
    "the trajectory data\",\"type\":\"object\"},\"body_coordinate_system_type\":{\""
    "description\":\"BODY coordinate frame (NED: North-East-Down, ENU: "
    "East-North-Up), default: NED\",\"enum\":[\"NED\",\"ENU\"],\"type\":\"string\"},\"s"
    "ocs_to_rocs_matrix\":{\"items\":{\"items\":{\"type\":\"number\",\"description\":\""
    "columns\"},\"maxItems\":4,\"type\":\"array\",\"minItems\":4,\"description\":\"rows"
    "\"},\"maxItems\":4,\"description\":\"Coordinate Transformation Matrix to "
    "transform from Scanner's Own Coordinate System to Record Coordinate "
    "System. 4x4 matrix stored as two dimensional array, row major order.\","
    "\"minItems\":4,\"type\":\"array\"},\"trajectory_file\":{\"properties\":{\"file_ex"
    "tension\":{\"type\":\"string\",\"description\":\"Trajectory file extension, "
    "without the leading "
    "dot\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC 4122)\"}},\"description\":\"Trajectory data used "
    "for georeferencing of the point cloud\",\"required\":[\"file_extension\"],\""
    "type\":\"object\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"socs_to_body_matrix\":[[-0.269827776749716,-0.723017716139738,0.63595"
    "4678449952,0.0],[0.962908599449764,-0.20260517250352,0.178208229833847"
    ",0.0],[0.0,0.660451759194338,0.7508684796801,0.0],[0.0,0.0,0.0,1.0]],\""
    "trajectory_offsets\":{\"offset_height\":-0.2,\"offset_north\":0.07,\"version"
    "\":0,\"offset_roll\":0.03,\"offset_pitch\":0.01,\"offset_east\":0.15,\"offset_"
    "time\":18.007,\"offset_yaw\":-0.45},\"body_coordinate_system_type\":\"NED\",\""
    "trajectory_file\":{\"file_extension\":\"pofx\",\"file_uuid\":\"93a03615-66c0-4"
    "bea-8ff8-c577378fe660\"}}"
};

// Map of item names
const MetaDataItemInfo RDB_RIEGL_ITEM_NAMES = {
    /* name        */ "riegl.item_names",
    /* title       */ "Item Names",
    /* description */ "Map of item names",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"additionalProper"
    "ties\":false,\"description\":\"Map of item names\",\"title\":\"Item Names\",\"pa"
    "tternProperties\":{\"^-?[0-9]+$\":{\"type\":\"string\",\"description\":\"One "
    "field per item, field name is item id, field value is item "
    "name\"}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"2\":\"Name of item with id 2\",\"-1\":\"Name of item with id -1\",\"1\":\"Name"
    " of item with id 1\",\"47\":\"Name of item with id 47\"}"
};

// License keys for software features
const MetaDataItemInfo RDB_RIEGL_LICENSES = {
    /* name        */ "riegl.licenses",
    /* title       */ "Software License Keys",
    /* description */ "License keys for software features",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"additionalProper"
    "ties\":false,\"description\":\"License keys for software "
    "features\",\"title\":\"Software License Keys\",\"patternProperties\":{\"^.*$\":"
    "{\"items\":{\"type\":\"string\",\"description\":\"License key (example: "
    "'46AE032A - 39882AC4 - 9EC0A184 - "
    "6F163D73')\"},\"minItems\":1,\"type\":\"array\",\"description\":\"Each field of "
    "the object represents a feature and holds a list of license keys, "
    "where the field name is the feature name.\"}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"Georeferencing\":[\"46AE032A - 39882AC4 - 9EC0A184 - 6F163D73\"],\"Full "
    "Waveform Analysis Topography\":[\"0FD5FF07 - 011A1255 - 9F76CACA - "
    "8D2ED557\"],\"MTA resolution\":[\"468E020A - 39A922E4 - B681A184 - "
    "673E3D72\"],\"Full Waveform Analysis Topography with GPU "
    "support\":[\"8AB44126 - 23B92250 - 16E2689F - 34EF7E7B\"]}"
};

// Parameters for MTA processing
const MetaDataItemInfo RDB_RIEGL_MTA_SETTINGS = {
    /* name        */ "riegl.mta_settings",
    /* title       */ "MTA Settings",
    /* description */ "Parameters for MTA processing",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"MTA Settings\",\"description\":\"Parameters for "
    "MTA processing\",\"properties\":{\"zone_width\":{\"minimum\":0,\"description\":"
    "\"Width of a MTA zone in meter.\",\"type\":\"number\"},\"zone_count\":{\"minimu"
    "m\":0,\"description\":\"Maximum number of MTA zones.\",\"maximum\":255,\"type\""
    ":\"integer\"},\"modulation_depth\":{\"minimum\":0,\"description\":\"Depth of "
    "pulse position modulation in meter.\",\"type\":\"number\"}},\"$schema\":\"http"
    "://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"zone_width\":149.896225,\"zone_count\":23,\"modulation_depth\":9.368514}"
};

// Lookup table for range correction based on raw range
const MetaDataItemInfo RDB_RIEGL_NEAR_RANGE_CORRECTION = {
    /* name        */ "riegl.near_range_correction",
    /* title       */ "Near Range Correction Table",
    /* description */ "Lookup table for range correction based on raw range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"content\":{\"items\":{\"type\":\"number\"},\"minItems\":1,\"type"
    "\":\"array\",\"maxItems\":2000,\"description\":\"Correction value [m] to be "
    "added to the raw range\"},\"delta\":{\"type\":\"number\",\"description\":\"Delta"
    " between table entries [m], first entry is at range = 0 "
    "m\"}},\"required\":[\"delta\",\"content\"],\"description\":\"Lookup table for "
    "range correction based on raw range\",\"title\":\"Near Range Correction Ta"
    "ble\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"objec"
    "t\"}"
    ,
    /* example: */
    "{\"content\":[0.0],\"delta\":0.512}"
};

// Standard deviation for range and amplitude as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_NOISE_ESTIMATES = {
    /* name        */ "riegl.noise_estimates",
    /* title       */ "Noise Estimates",
    /* description */ "Standard deviation for range and amplitude as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"range_sigma\":{\"items\":{\"type\":\"number\"},\"description\":"
    "\"Sigma range [m]\",\"type\":\"array\"},\"amplitude\":{\"items\":{\"type\":\"number"
    "\"},\"description\":\"Amplitude [dB]\",\"type\":\"array\"},\"amplitude_sigma\":{\""
    "items\":{\"type\":\"number\"},\"description\":\"Sigma amplitude [dB]\",\"type\":\""
    "array\"}},\"required\":[\"amplitude\",\"range_sigma\",\"amplitude_sigma\"],\"des"
    "cription\":\"Standard deviation for range and amplitude as a function of"
    " amplitude\",\"title\":\"Noise Estimates\",\"$schema\":\"http://json-schema.or"
    "g/draft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"range_sigma\":[0.065,0.056,0.046,0.038,0.032,0.027,0.024,0.021,0.018,"
    "0.016,0.014],\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0"
    "],\"amplitude_sigma\":[0.988,0.988,0.875,0.774,0.686,0.608,0.54,0.482,0."
    "432,0.39,0.354]}"
};

// Notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_NOTCH_FILTER = {
    /* name        */ "riegl.notch_filter",
    /* title       */ "Notch Filter",
    /* description */ "Notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"amplitude_maximum\":{\"minimum\":0,\"description\":\"Maximum"
    " amplitude "
    "[dB]\",\"type\":\"number\"},\"range_maximum\":{\"description\":\"Maximum range "
    "[m]\",\"type\":\"number\"},\"range_minimum\":{\"description\":\"Minimum range [m"
    "]\",\"type\":\"number\"}},\"required\":[\"range_minimum\",\"range_maximum\",\"ampl"
    "itude_maximum\"],\"description\":\"Notch filter parameters for window "
    "glass echoes\",\"title\":\"Notch Filter\",\"$schema\":\"http://json-schema.org"
    "/draft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"amplitude_maximum\":18.0,\"range_maximum\":0.2,\"range_minimum\":-0.5}"
};

// Details about the pixels contained in the file
const MetaDataItemInfo RDB_RIEGL_PIXEL_INFO = {
    /* name        */ "riegl.pixel_info",
    /* title       */ "Pixel Information",
    /* description */ "Details about the pixels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"size_llcs\":{\"$ref\":\"#/definitions/pixel_size\",\"descrip"
    "tion\":\"Size of pixels in a locally levelled cartesian coordinate "
    "system (xy). This is only used for pixels based on a map projection.\"}"
    ",\"size\":{\"$ref\":\"#/definitions/pixel_size\",\"description\":\"Size of "
    "pixels in file coordinate system.\"}},\"required\":[\"size\"],\"definitions\""
    ":{\"pixel_size\":{\"items\":{\"minimum\":0,\"description\":\"Length of pixel "
    "edge [m].\",\"type\":\"number\"},\"maxItems\":2,\"description\":\"Size of "
    "pixels.\",\"minItems\":2,\"type\":\"array\"}},\"description\":\"Details about "
    "the pixels contained in the file\",\"title\":\"Pixel Information\",\"$schema"
    "\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"size_llcs\":[0.5156575252891171,0.5130835356683303],\"size\":[0.5971642"
    "834779395,0.5971642834779395]}"
};

// Details about the plane patch matching process
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_MATCHING = {
    /* name        */ "riegl.plane_patch_matching",
    /* title       */ "Plane Patch Matching",
    /* description */ "Details about the plane patch matching process",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"plane_patch_file_one\":{\"$ref\":\"#/definitions/file_refe"
    "rence\",\"description\":\"Reference to the plane patch file one\"},\"plane_p"
    "atch_file_two\":{\"$ref\":\"#/definitions/file_reference\",\"description\":\"R"
    "eference to the plane patch file two\"}},\"required\":[\"plane_patch_file_"
    "one\",\"plane_patch_file_two\"],\"definitions\":{\"file_reference\":{\"propert"
    "ies\":{\"file_uuid\":{\"type\":\"string\",\"description\":\"Plane patch file's "
    "Universally Unique Identifier (RFC "
    "4122)\"},\"file_path\":{\"type\":\"string\",\"description\":\"Path of the plane "
    "patch file relative to the match file\"}},\"description\":\"Reference to a"
    " plane patch file\",\"required\":[\"file_uuid\",\"file_path\"],\"type\":\"object"
    "\"}},\"description\":\"Details about the plane patch matching "
    "process\",\"title\":\"Plane Patch Matching\",\"$schema\":\"http://json-schema."
    "org/draft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"plane_patch_file_one\":{\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b"
    "4213\",\"file_path\":\"Record009_Line001/191025_121410_Scanner_1.ptch\"},\"p"
    "lane_patch_file_two\":{\"file_uuid\":\"fa47d509-a64e-49ce-8b14-ff3130fbefa"
    "9\",\"file_path\":\"project.ptch\"}}"
};

// Statistics about plane patches found by plane patch extractor
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_STATISTICS = {
    /* name        */ "riegl.plane_patch_statistics",
    /* title       */ "Plane Patch Statistics",
    /* description */ "Statistics about plane patches found by plane patch extractor",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Plane Patch "
    "Statistics\",\"description\":\"Statistics about plane patches found by "
    "plane patch extractor\",\"properties\":{\"total_area\":{\"description\":\"sum "
    "of all plane patch areas [m\\u00b2]\",\"type\":\"number\"},\"total_horizontal"
    "_area\":{\"description\":\"sum of all plane patch areas projected to "
    "horizontal plane [m\\u00b2]\",\"type\":\"number\"}},\"$schema\":\"http://json-s"
    "chema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"total_area\":14007.965,\"total_horizontal_area\":13954.601}"
};

// Settings and classes for plane slope classification
const MetaDataItemInfo RDB_RIEGL_PLANE_SLOPE_CLASS_INFO = {
    /* name        */ "riegl.plane_slope_class_info",
    /* title       */ "Plane Slope Class Info",
    /* description */ "Settings and classes for plane slope classification",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"settings\":{\"description\":\"Classification settings, "
    "details see documentation of rdbplanes\",\"oneOf\":[{\"$ref\":\"#/definition"
    "s/method-1\"},{\"$ref\":\"#/definitions/method-2\"}],\"type\":\"object\"},\"clas"
    "ses\":{\"description\":\"Class definition table\",\"additionalProperties\":fa"
    "lse,\"patternProperties\":{\"^[0-9]+$\":{\"type\":\"string\",\"description\":\"on"
    "e field per class, field name is class number, field value is class na"
    "me\"}},\"type\":\"object\"}},\"required\":[\"settings\",\"classes\"],\"definitions"
    "\":{\"method-1\":{\"properties\":{\"plane_classification_method\":{\"minimum\":"
    "1,\"description\":\"method ID (=1)\",\"maximum\":1,\"type\":\"integer\"},\"maximu"
    "m_inclination_angle_horizontal\":{\"minimum\":-360.0,\"description\":\"maxim"
    "um inclination angle of horizontal plane patches "
    "[deg]\",\"maximum\":360.0,\"type\":\"number\"}},\"description\":\"Classification"
    " method 1\",\"required\":[\"plane_classification_method\",\"maximum_inclinat"
    "ion_angle_horizontal\"],\"type\":\"object\"},\"method-2\":{\"properties\":{\"slo"
    "ping_plane_classes_minimum_angle\":{\"minimum\":-360.0,\"description\":\"min"
    "imum inclination angle of sloping plane patches [deg]\",\"maximum\":360.0"
    ",\"type\":\"number\"},\"plane_classification_method\":{\"minimum\":2,\"descript"
    "ion\":\"method ID (=2)\",\"maximum\":2,\"type\":\"integer\"},\"sloping_plane_cla"
    "sses_maximum_angle\":{\"minimum\":-360.0,\"description\":\"maximum "
    "inclination angle of sloping plane patches "
    "[deg]\",\"maximum\":360.0,\"type\":\"number\"}},\"description\":\"Classification"
    " method 2\",\"required\":[\"plane_classification_method\",\"sloping_plane_cl"
    "asses_minimum_angle\",\"sloping_plane_classes_maximum_angle\"],\"type\":\"ob"
    "ject\"}},\"description\":\"Settings and classes for plane slope "
    "classification\",\"title\":\"Plane Slope Class Info\",\"$schema\":\"http://jso"
    "n-schema.org/draft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"settings\":{\"sloping_plane_classes_minimum_angle\":10.0,\"plane_classif"
    "ication_method\":2,\"sloping_plane_classes_maximum_angle\":70.0},\"classes"
    "\":{\"7\":\"vertical, pointing south\",\"5\":\"sloping, pointing up and "
    "west\",\"12\":\"sloping, pointing down and north\",\"6\":\"vertical, pointing "
    "east\",\"2\":\"sloping, pointing up and east\",\"14\":\"horizontal, pointing "
    "down\",\"1\":\"horizontal, pointing up\",\"3\":\"sloping, pointing up and "
    "south\",\"13\":\"sloping, pointing down and west\",\"10\":\"sloping, pointing "
    "down and east\",\"8\":\"vertical, pointing north\",\"11\":\"sloping, pointing "
    "down and south\",\"4\":\"sloping, pointing up and north\",\"9\":\"vertical, "
    "pointing west\"}}"
};

// Grouping and sorting of point attributes for visualization purposes
const MetaDataItemInfo RDB_RIEGL_POINT_ATTRIBUTE_GROUPS = {
    /* name        */ "riegl.point_attribute_groups",
    /* title       */ "Point Attribute Groups",
    /* description */ "Grouping and sorting of point attributes for visualization purposes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"additionalProper"
    "ties\":false,\"description\":\"Grouping and sorting of point attributes "
    "for visualization purposes\",\"title\":\"Point Attribute Groups\",\"patternP"
    "roperties\":{\"^.*$\":{\"items\":{\"type\":\"string\",\"description\":\"Point "
    "attribute full name or name pattern (perl regular expression "
    "syntax)\"},\"minItems\":1,\"type\":\"array\",\"description\":\"Each field of the"
    " object represents a point attribute group and holds a list of point "
    "attributes, where the field name is the group "
    "name.\"}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"Time\":[\"riegl.timestamp\"],\"Coordinates/Vectors\":[\"riegl.xyz\",\"riegl."
    "range\",\"riegl.theta\",\"riegl.phi\"],\"Secondary "
    "Attributes\":[\"riegl.mirror_facet\",\"riegl.waveform_available\"],\"Other "
    "Attributes\":[\"riegl.selected\",\"riegl.visible\"],\"Primary "
    "Attributes\":[\"riegl.reflectance\",\"riegl.amplitude\",\"riegl.deviation\"]}"
};

// Details about point cloud files
const MetaDataItemInfo RDB_RIEGL_POINTCLOUD_INFO = {
    /* name        */ "riegl.pointcloud_info",
    /* title       */ "Point Cloud Information",
    /* description */ "Details about point cloud files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Point Cloud "
    "Information\",\"description\":\"Details about point cloud "
    "files\",\"properties\":{\"project\":{\"type\":\"string\",\"description\":\"Project"
    " name\"},\"comments\":{\"type\":\"string\",\"description\":\"Comments\"},\"field_o"
    "f_application\":{\"type\":\"string\",\"enum\":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"M"
    "LS\",\"ULS\",\"ALS\",\"BLS\",\"ILS\"],\"description\":\"Field of "
    "application\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"project\":\"Campaign 4\",\"comments\":\"Line "
    "3\",\"field_of_application\":\"ALS\"}"
};

// Estimated position and orientation information
const MetaDataItemInfo RDB_RIEGL_POSE_ESTIMATION = {
    /* name        */ "riegl.pose_estimation",
    /* title       */ "Pose Estimation",
    /* description */ "Estimated position and orientation information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"barometric_height_amsl\":{\"type\":\"number\",\"description\""
    ":\"Altitude determined based on the atmospheric pressure according to "
    "the standard atmosphere laws [m].\"},\"orientation\":{\"properties\":{\"yaw\""
    ":{\"minimum\":-360,\"type\":\"number\",\"maximum\":360,\"description\":\"Yaw "
    "angle about scanner Z-axis [deg]\"},\"pitch\":{\"minimum\":-360,\"type\":\"num"
    "ber\",\"maximum\":360,\"description\":\"Pitch angle about scanner Y-axis [de"
    "g]\"},\"pitch_accuracy\":{\"minimum\":0,\"type\":\"number\",\"exclusiveMinimum\":"
    "true,\"description\":\"Pitch angle accuracy [deg]\"},\"yaw_accuracy\":{\"mini"
    "mum\":0,\"type\":\"number\",\"exclusiveMinimum\":true,\"description\":\"Yaw "
    "angle accuracy [deg]\"},\"roll_accuracy\":{\"minimum\":0,\"type\":\"number\",\"e"
    "xclusiveMinimum\":true,\"description\":\"Roll angle accuracy [deg]\"},\"roll"
    "\":{\"minimum\":-360,\"type\":\"number\",\"maximum\":360,\"description\":\"Roll "
    "angle about scanner X-axis [deg]\"}},\"type\":\"object\",\"required\":[\"roll\""
    ",\"pitch\",\"yaw\",\"roll_accuracy\",\"pitch_accuracy\",\"yaw_accuracy\"],\"descr"
    "iption\":\"Orientation values and orientation accuracies, measured with "
    "IMU or inclination sensors.\"},\"position\":{\"properties\":{\"crs\":{\"proper"
    "ties\":{\"wkt\":{\"type\":\"string\",\"description\":\"\\\"Well-Known Text\\\" "
    "string, OGC WKT dialect (see http://www.opengeospatial.org/standards/w"
    "kt-crs)\"},\"epsg\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"EPSG "
    "code\"}},\"description\":\"Global Coordinate Reference System\",\"required\":"
    "[\"epsg\"],\"type\":\"object\"},\"coordinate_1\":{\"type\":\"number\",\"description"
    "\":\"Coordinate 1 as defined by axis 1 of the specified CRS (e.g., X, La"
    "titude)\"},\"horizontal_accuracy\":{\"minimum\":0,\"type\":\"number\",\"exclusiv"
    "eMinimum\":true,\"description\":\"Horizontal accuracy "
    "[m]\"},\"coordinate_3\":{\"type\":\"number\",\"description\":\"Coordinate 3 as "
    "defined by axis 3 of the specified CRS (e.g., Z, Altitude)\"},\"vertical"
    "_accuracy\":{\"minimum\":0,\"type\":\"number\",\"exclusiveMinimum\":true,\"descr"
    "iption\":\"Vertical accuracy "
    "[m]\"},\"coordinate_2\":{\"type\":\"number\",\"description\":\"Coordinate 2 as "
    "defined by axis 2 of the specified CRS (e.g., Y, Longitude)\"}},\"type\":"
    "\"object\",\"required\":[\"coordinate_1\",\"coordinate_2\",\"coordinate_3\",\"hor"
    "izontal_accuracy\",\"vertical_accuracy\",\"crs\"],\"description\":\"Position "
    "coordinates and position accuracy values as measured by GNSS in the "
    "specified Coordinate Reference System "
    "(CRS)\"}},\"required\":[\"orientation\"],\"description\":\"Estimated position "
    "and orientation information as measured by GNSS, IMU or inclination "
    "sensors\",\"title\":\"Pose Estimation\",\"$schema\":\"http://json-schema.org/d"
    "raft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"barometric_height_amsl\":386.7457796227932,\"orientation\":{\"yaw\":101.8"
    "7293630292045,\"pitch\":1.509153024827064,\"pitch_accuracy\":0.00943378393"
    "6875745,\"yaw_accuracy\":1.0094337839368757,\"roll_accuracy\":0.0094337839"
    "36875745,\"roll\":3.14743073066123},\"position\":{\"crs\":{\"wkt\":\"GEOGCS[\\\"W"
    "GS84 / Geographic\\\",DATUM[\\\"WGS84\\\",SPHEROID[\\\"WGS84\\\",6378137.000,298"
    ".257223563,AUTHORITY[\\\"EPSG\\\",\\\"7030\\\"]],AUTHORITY[\\\"EPSG\\\",\\\"6326\\\"]]"
    ",PRIMEM[\\\"Greenwich\\\",0.0000000000000000,AUTHORITY[\\\"EPSG\\\",\\\"8901\\\"]]"
    ",UNIT[\\\"Degree\\\",0.01745329251994329547,AUTHORITY[\\\"EPSG\\\",\\\"9102\\\"]],"
    "AXIS[\\\"Latitude\\\",NORTH],AXIS[\\\"Longitude\\\",EAST],AUTHORITY[\\\"EPSG\\\",\\"
    "\"4979\\\"]]\",\"epsg\":4979},\"coordinate_1\":48.655799473,\"horizontal_accura"
    "cy\":0.810699999332428,\"coordinate_3\":362.7124938964844,\"vertical_accur"
    "acy\":1.3314999341964722,\"coordinate_2\":15.645033406}}"
};

// Details on position and orientation sensors
const MetaDataItemInfo RDB_RIEGL_POSE_SENSORS = {
    /* name        */ "riegl.pose_sensors",
    /* title       */ "Pose Sensors",
    /* description */ "Details on position and orientation sensors",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"accelerometer\":{\"properties\":{\"unit\":{\"minimum\":0,\"des"
    "cription\":\"Unit of raw data and calibration values, 1 LSB in 9.81 m/s\\"
    "u00b2\",\"exclusiveMinimum\":true,\"type\":\"number\"},\"origin\":{\"$ref\":\"#/de"
    "finitions/vector\",\"description\":\"Sensor origin in SOCS [m] at frame "
    "angle = "
    "0\"},\"y_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Y"
    " axis of sensor at frame angle = 0\"},\"relative_nonlinearity\":{\"$ref\":\""
    "#/definitions/vector\",\"description\":\"Relative nonlinearity, dimensionl"
    "ess\"},\"z_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive"
    " Z axis of sensor at frame angle = "
    "0\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to be"
    " subtracted from raw measurement values\"},\"x_axis\":{\"$ref\":\"#/definiti"
    "ons/vector\",\"description\":\"Sensitive X axis of sensor at frame angle ="
    " 0\"}},\"description\":\"Accelerometer details\",\"required\":[\"unit\",\"x_axis"
    "\",\"y_axis\",\"z_axis\",\"offset\",\"origin\",\"relative_nonlinearity\"],\"type\":"
    "\"object\"},\"magnetic_field_sensor\":{\"properties\":{\"unit\":{\"minimum\":0,\""
    "description\":\"Unit of raw data and calibration values, 1 LSB in nT\",\"e"
    "xclusiveMinimum\":true,\"type\":\"number\"},\"y_axis\":{\"$ref\":\"#/definitions"
    "/vector\",\"description\":\"Sensitive Y axis of sensor at frame angle = 0\""
    "},\"relative_nonlinearity\":{\"$ref\":\"#/definitions/vector\",\"description\""
    ":\"Relative nonlinearity, dimensionless\"},\"z_axis\":{\"$ref\":\"#/definitio"
    "ns/vector\",\"description\":\"Sensitive Z axis of sensor at frame angle = "
    "0\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to be"
    " subtracted from raw measurement values\"},\"fixed\":{\"$ref\":\"#/definitio"
    "ns/vector\",\"description\":\"Distortion of magnetic field caused by "
    "non-rotating scanner part\"},\"x_axis\":{\"$ref\":\"#/definitions/vector\",\"d"
    "escription\":\"Sensitive X axis of sensor at frame angle = "
    "0\"}},\"description\":\"Magnetic Field Sensor details\",\"required\":[\"unit\","
    "\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"fixed\",\"relative_nonlinearity\"],\""
    "type\":\"object\"},\"gyroscope\":{\"properties\":{\"unit\":{\"minimum\":0,\"descri"
    "ption\":\"Unit of raw data and calibration values, 1 LSB in rad/s\",\"excl"
    "usiveMinimum\":true,\"type\":\"number\"},\"origin\":{\"$ref\":\"#/definitions/ve"
    "ctor\",\"description\":\"Sensor origin in SOCS [m] at frame angle = "
    "0\"},\"y_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Y"
    " axis of sensor at frame angle = 0\"},\"relative_nonlinearity\":{\"$ref\":\""
    "#/definitions/vector\",\"description\":\"Relative nonlinearity, dimensionl"
    "ess\"},\"z_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive"
    " Z axis of sensor at frame angle = "
    "0\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to be"
    " subtracted from raw measurement values\"},\"x_axis\":{\"$ref\":\"#/definiti"
    "ons/vector\",\"description\":\"Sensitive X axis of sensor at frame angle ="
    " 0\"}},\"description\":\"Gyroscope details\",\"required\":[\"unit\",\"x_axis\",\"y"
    "_axis\",\"z_axis\",\"offset\",\"origin\",\"relative_nonlinearity\"],\"type\":\"obj"
    "ect\"}},\"required\":[\"gyroscope\",\"accelerometer\",\"magnetic_field_sensor\""
    "],\"definitions\":{\"vector\":{\"items\":{\"description\":\"Index 0=X, 1=Y, 2=Z"
    " component\",\"type\":\"number\"},\"minItems\":3,\"maxItems\":3,\"type\":\"array\"}"
    "},\"description\":\"Details on position and orientation "
    "sensors\",\"title\":\"Pose Sensors\",\"$schema\":\"http://json-schema.org/draf"
    "t-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"accelerometer\":{\"unit\":6.666666740784422e-05,\"origin\":[0.02690000087"
    "0227814,-0.03999999910593033,-0.08950000256299973],\"y_axis\":[-7.027288"
    "913726807,-44.12333679199219,14952.3701171875],\"relative_nonlinearity\""
    ":[0.0,0.0,0.0],\"z_axis\":[1.639882206916809,15166.744140625,-116.997428"
    "89404297],\"offset\":[-733.3636474609375,58.969032287597656,1060.2550048"
    "828125],\"x_axis\":[-15008.123046875,56.956390380859375,-60.517566680908"
    "2]},\"magnetic_field_sensor\":{\"unit\":91.74311828613281,\"y_axis\":[0.0002"
    "7888521435670555,-0.011427424848079681,-5.204829722060822e-05],\"relati"
    "ve_nonlinearity\":[0.0,0.0,0.0],\"z_axis\":[0.00041987866279669106,7.8769"
    "77906562388e-05,0.011407104320824146],\"offset\":[-23812.052734375,5606."
    "57666015625,2493.28125],\"fixed\":[-1576.010498046875,1596.081787109375,"
    "0.0],\"x_axis\":[-0.011162743903696537,-2.315962774446234e-05,0.00016818"
    "844596855342]},\"gyroscope\":{\"unit\":0.00014544410805683583,\"origin\":[0."
    "026900000870227814,-0.03999999910593033,-0.08950000256299973],\"y_axis\""
    ":[-0.440765917301178,-0.7897399663925171,119.5894775390625],\"relative_"
    "nonlinearity\":[2.888176311444113e-07,1.06274164579645e-07,-1.718629508"
    "0634935e-39],\"z_axis\":[0.555869996547699,119.22135162353516,0.46758502"
    "7217865],\"offset\":[-50.92609786987305,146.15643310546875,62.4327278137"
    "207],\"x_axis\":[-121.195556640625,0.8219714164733887,0.2313031703233719"
    "]}}"
};

// Laser pulse position modulation used for MTA resolution
const MetaDataItemInfo RDB_RIEGL_PULSE_POSITION_MODULATION = {
    /* name        */ "riegl.pulse_position_modulation",
    /* title       */ "Pulse Position Modulation",
    /* description */ "Laser pulse position modulation used for MTA resolution",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"phase_step\":{\"minimum\":0,\"description\":\"Step width in "
    "phase of modulation code from line to line\",\"maximum\":255,\"type\":\"inte"
    "ger\"},\"length\":{\"minimum\":0,\"description\":\"Length of code\",\"maximum\":2"
    "55,\"type\":\"integer\"},\"pulse_interval\":{\"items\":{\"minimum\":0,\"type\":\"nu"
    "mber\"},\"description\":\"Explicit table of the pulse position modulation "
    "used for MTA resolution. Table gives times between successive laser "
    "pulses in seconds.\",\"type\":\"array\"},\"num_mod_ampl\":{\"minimum\":0,\"descr"
    "iption\":\"Number of different modulation amplitudes (2: binary modulati"
    "on)\",\"maximum\":255,\"type\":\"integer\"},\"code_phase_mode\":{\"minimum\":0,\"d"
    "escription\":\"0: no synchronization, 1: toggle between 2 phases, 2: "
    "increment with phase_increment\",\"maximum\":255,\"type\":\"integer\"}},\"requ"
    "ired\":[\"length\",\"num_mod_ampl\",\"pulse_interval\"],\"description\":\"Laser "
    "pulse position modulation used for MTA resolution\",\"title\":\"Pulse "
    "Position Modulation\",\"$schema\":\"http://json-schema.org/draft-04/schema"
    "#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"phase_step\":5,\"length\":31,\"pulse_interval\":[2.759375e-06,2.759375e-0"
    "6,2.759375e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.759375e-06,2.8"
    "21875e-06,2.759375e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.759375"
    "e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.821875e-06,"
    "2.759375e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.821875e-06,2.759"
    "375e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.821875e-"
    "06,2.759375e-06,2.821875e-06],\"num_mod_ampl\":2,\"code_phase_mode\":2}"
};

// Statistics about target distance wrt. SOCS origin
const MetaDataItemInfo RDB_RIEGL_RANGE_STATISTICS = {
    /* name        */ "riegl.range_statistics",
    /* title       */ "Range Statistics",
    /* description */ "Statistics about target distance wrt. SOCS origin",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"std_dev\":{\"description\":\"Standard "
    "deviation\",\"type\":\"number\"},\"minimum\":{\"description\":\"Minimum "
    "value\",\"type\":\"number\"},\"average\":{\"description\":\"Average "
    "value\",\"type\":\"number\"},\"maximum\":{\"description\":\"Maximum value\",\"type"
    "\":\"number\"}},\"required\":[\"minimum\",\"average\",\"maximum\",\"std_dev\"],\"des"
    "cription\":\"Statistics about target distance wrt. SOCS "
    "origin\",\"title\":\"Range Statistics\",\"$schema\":\"http://json-schema.org/d"
    "raft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"std_dev\":24.349,\"minimum\":0.919,\"average\":15.49738,\"maximum\":574.35}"
};

// Receiver Internals
const MetaDataItemInfo RDB_RIEGL_RECEIVER_INTERNALS = {
    /* name        */ "riegl.receiver_internals",
    /* title       */ "Receiver Internals",
    /* description */ "Receiver Internals",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"nt\":{\"minimum\":0,\"description\":\"Number of traces\",\"max"
    "imum\":255,\"type\":\"integer\"},\"sr\":{\"minimum\":0,\"description\":\"Sample "
    "rate [Hz]\",\"exclusiveMinimum\":true,\"type\":\"number\"},\"mw\":{\"minimum\":0,"
    "\"description\":\"Maximum weight\",\"exclusiveMinimum\":true,\"maximum\":4095,"
    "\"type\":\"number\"},\"a\":{\"items\":{\"type\":\"number\"},\"minItems\":1,\"maxItems"
    "\":256,\"description\":\"Amplitude "
    "[dB]\",\"type\":\"array\"},\"ns\":{\"minimum\":0,\"description\":\"Number of sampl"
    "es\",\"maximum\":4095,\"type\":\"integer\"},\"ex\":{\"description\":\"DEPRECATED, "
    "use 'riegl.exponential_decomposition' "
    "instead\",\"type\":\"object\"},\"si\":{\"minimum\":0,\"description\":\"Start index"
    " (hw_start)\",\"maximum\":255,\"type\":\"number\"},\"tbl\":{\"items\":{\"$ref\":\"#/"
    "definitions/fp_table\"},\"minItems\":1,\"description\":\"various internal da"
    "ta\",\"type\":\"array\"},\"t\":{\"patternProperties\":{\"^[0-9]+$\":{\"$ref\":\"#/de"
    "finitions/fp\",\"description\":\"one field per channel, field name is "
    "channel index\"}},\"additionalProperties\":false,\"type\":\"object\"}},\"defin"
    "itions\":{\"fp_table_row\":{\"items\":{\"type\":\"number\"},\"minItems\":1,\"maxIt"
    "ems\":2048,\"type\":\"array\"},\"fp\":{\"properties\":{\"s\":{\"items\":{\"items\":{\""
    "type\":\"number\"},\"minItems\":1,\"maxItems\":4096,\"type\":\"array\"},\"minItems"
    "\":1,\"maxItems\":256,\"type\":\"array\"},\"w\":{\"items\":{\"items\":{\"type\":\"numb"
    "er\"},\"minItems\":5,\"maxItems\":5,\"type\":\"array\"},\"minItems\":1,\"maxItems\""
    ":256,\"type\":\"array\"}},\"description\":\"Fingerprint values\",\"required\":[\""
    "s\",\"w\"],\"type\":\"object\"},\"fp_table\":{\"properties\":{\"tc\":{\"min\":0,\"max\""
    ":255,\"description\":\"table data type "
    "code\",\"type\":\"integer\"},\"ny\":{\"min\":1,\"max\":2048,\"description\":\"number"
    " of y entries\",\"type\":\"integer\"},\"nx\":{\"min\":1,\"max\":2048,\"description"
    "\":\"number of x entries\",\"type\":\"integer\"},\"ch\":{\"min\":0,\"max\":255,\"des"
    "cription\":\"channel number\",\"type\":\"integer\"},\"tv\":{\"items\":{\"oneOf\":[{"
    "\"$ref\":\"#/definitions/fp_table_row\"},{\"type\":\"number\"}]},\"minItems\":1,"
    "\"maxItems\":2048,\"type\":\"array\"}},\"desription\":\"scanner internal data\","
    "\"required\":[\"ch\",\"tc\",\"nx\",\"ny\",\"tv\"],\"type\":\"object\"}},\"description\":"
    "\"Receiver Internals\",\"title\":\"Receiver Internals\",\"$schema\":\"http://js"
    "on-schema.org/draft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"nt\":128,\"sr\":7959997000.0,\"mw\":31,\"a\":[-1.55],\"ns\":400,\"si\":48,\"tbl\""
    ":[{\"tc\":1,\"ny\":2,\"nx\":5,\"ch\":0,\"tv\":[[1,2,3,4,5],[1.1,2.2,3.3,4.4,5.5]"
    "]}],\"t\":{\"0\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[78,86,126,134,31],[7"
    "8,86,126,134,31]]},\"1\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[78,86,126,"
    "134,31],[78,86,126,134,31]]}}}"
};

// Lookup table for reflectance calculation based on amplitude and range
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CALCULATION = {
    /* name        */ "riegl.reflectance_calculation",
    /* title       */ "Reflectance Calculation Table",
    /* description */ "Lookup table for reflectance calculation based on amplitude and range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"content\":{\"items\":{\"type\":\"number\"},\"minItems\":1,\"type"
    "\":\"array\",\"maxItems\":2000,\"description\":\"Correction value [dB] to be "
    "added to the amplitude\"},\"delta\":{\"type\":\"number\",\"description\":\"Delta"
    " between table entries [m], first entry is at range = 0 "
    "m\"}},\"required\":[\"delta\",\"content\"],\"description\":\"Lookup table for "
    "reflectance calculation based on amplitude and "
    "range\",\"title\":\"Reflectance Calculation Table\",\"$schema\":\"http://json-"
    "schema.org/draft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"content\":[-33.01],\"delta\":0.150918}"
};

// Range-dependent and scan-angle-dependent correction of reflectance reading
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CORRECTION = {
    /* name        */ "riegl.reflectance_correction",
    /* title       */ "Near-Range Reflectance Correction",
    /* description */ "Range-dependent and scan-angle-dependent correction of reflectance reading",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"reflectance_correction_db\":{\"items\":{\"items\":{\"type\":\""
    "number\",\"description\":\"columns (each value corresponds to an "
    "angle)\"},\"type\":\"array\",\"description\":\"rows (each array corresponds to"
    " a range)\"},\"description\":\"Near range reflectance correction in dB as "
    "a function of range over angle\",\"type\":\"array\"},\"line_angles_deg\":{\"it"
    "ems\":{\"type\":\"number\"},\"description\":\"Angle [deg]\",\"type\":\"array\"},\"ra"
    "nges_m\":{\"items\":{\"type\":\"number\"},\"description\":\"Range [m]\",\"type\":\"a"
    "rray\"}},\"required\":[\"ranges_m\",\"line_angles_deg\",\"reflectance_correcti"
    "on_db\"],\"description\":\"Range-dependent and scan-angle-dependent "
    "correction of reflectance reading\",\"title\":\"Near-range reflectance cor"
    "rection\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"o"
    "bject\"}"
    ,
    /* example: */
    "{\"reflectance_correction_db\":[[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0."
    "01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0"
    ".3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01]],\"li"
    "ne_angles_deg\":[0.0,0.5,1.0,1.5,1.0,2.0,2.5,3.0,3.5,4.0],\"ranges_m\":[0"
    ".0,1.0,2.0,3.0]}"
};

// Scan pattern description
const MetaDataItemInfo RDB_RIEGL_SCAN_PATTERN = {
    /* name        */ "riegl.scan_pattern",
    /* title       */ "Scan Pattern",
    /* description */ "Scan pattern description",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Scan Pattern\",\"description\":\"Scan pattern description\",\"prop"
    "erties\":{\"segments\":{\"properties\":{\"list\":{\"items\":{\"properties\":{\"sto"
    "p\":{\"minimum\":0.0,\"type\":\"number\",\"maximum\":720.0,\"description\":\"Stop "
    "angle in SOCS [deg]\"},\"increment\":{\"minimum\":0.0,\"type\":\"number\",\"maxi"
    "mum\":90.0,\"description\":\"Increment of angle in SOCS [deg]\"},\"start\":{\""
    "minimum\":0.0,\"type\":\"number\",\"maximum\":360.0,\"description\":\"Start "
    "angle in SOCS [deg]\"}},\"type\":\"object\",\"required\":[\"start\",\"stop\",\"inc"
    "rement\"],\"description\":\"Line Scan Segment\"},\"type\":\"array\"},\"program\":"
    "{\"$ref\":\"#/definitions/program\"}},\"type\":\"object\",\"required\":[\"list\"],"
    "\"description\":\"Segmented Line Scan Pattern\"},\"line\":{\"properties\":{\"st"
    "op\":{\"minimum\":0.0,\"type\":\"number\",\"maximum\":720.0,\"description\":\"Stop"
    " angle in SOCS [deg]\"},\"increment\":{\"minimum\":0.0,\"type\":\"number\",\"max"
    "imum\":90.0,\"description\":\"Increment of angle in SOCS [deg]\"},\"start\":{"
    "\"minimum\":0.0,\"type\":\"number\",\"maximum\":360.0,\"description\":\"Start "
    "angle in SOCS [deg]\"},\"program\":{\"$ref\":\"#/definitions/program\"}},\"typ"
    "e\":\"object\",\"required\":[\"start\",\"stop\",\"increment\"],\"description\":\"Lin"
    "e Scan Pattern\"},\"rectangular\":{\"properties\":{\"program\":{\"$ref\":\"#/def"
    "initions/program\"},\"phi_start\":{\"minimum\":0.0,\"type\":\"number\",\"maximum"
    "\":360.0,\"description\":\"Start phi angle in SOCS [deg]\"},\"phi_stop\":{\"mi"
    "nimum\":0.0,\"type\":\"number\",\"maximum\":720.0,\"description\":\"Stop phi "
    "angle in SOCS [deg]\"},\"theta_increment\":{\"minimum\":0.0,\"type\":\"number\""
    ",\"maximum\":90.0,\"description\":\"Increment of theta angle in SOCS [deg]\""
    "},\"phi_increment\":{\"minimum\":0.0,\"type\":\"number\",\"maximum\":90.0,\"descr"
    "iption\":\"Increment of phi angle in SOCS [deg]\"},\"theta_stop\":{\"minimum"
    "\":0.0,\"type\":\"number\",\"maximum\":180.0,\"description\":\"Stop theta angle "
    "in SOCS [deg]\"},\"theta_start\":{\"minimum\":0.0,\"type\":\"number\",\"maximum\""
    ":180.0,\"description\":\"Start theta angle in SOCS [deg]\"}},\"type\":\"objec"
    "t\",\"required\":[\"phi_start\",\"phi_stop\",\"phi_increment\",\"theta_start\",\"t"
    "heta_stop\",\"theta_increment\"],\"description\":\"Rectangular Field Of View"
    " Scan Pattern\"}},\"definitions\":{\"program\":{\"properties\":{\"name\":{\"type"
    "\":\"string\",\"description\":\"Name of measurement program\"},\"laser_prr\":{\""
    "minimum\":0,\"type\":\"number\",\"exclusiveMinimum\":false,\"description\":\"Las"
    "er Pulse Repetition Rate "
    "[Hz]\"}},\"type\":\"object\",\"required\":[\"name\"],\"description\":\"Measurement"
    " program\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"rectangular\":{\"program\":{\"name\":\"High Speed\",\"laser_prr\":100000.0},\""
    "phi_start\":45.0,\"phi_stop\":270.0,\"theta_increment\":0.04,\"phi_increment"
    "\":0.04,\"theta_stop\":130.0,\"theta_start\":30.0}}"
};

// Details about laser shot files
const MetaDataItemInfo RDB_RIEGL_SHOT_INFO = {
    /* name        */ "riegl.shot_info",
    /* title       */ "Shot Information",
    /* description */ "Details about laser shot files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Shot Information\",\"description\":\"Details "
    "about laser shot files\",\"properties\":{\"shot_file\":{\"properties\":{\"file"
    "_extension\":{\"type\":\"string\",\"description\":\"Shot file extension, "
    "without the leading "
    "dot\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC 4122)\"}},\"required\":[\"file_extension\"],\"type\":\""
    "object\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"shot_file\":{\"file_extension\":\"sodx\",\"file_uuid\":\"26a00815-67c0-4bff-"
    "8fe8-c577378fe663\"}}"
};

// Point filters applied in addition to the application-defined filters
const MetaDataItemInfo RDB_RIEGL_STORED_FILTERS = {
    /* name        */ "riegl.stored_filters",
    /* title       */ "Stored Filters",
    /* description */ "Point filters applied in addition to the application-defined filters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"filters\":{\"items\":{\"properties\":{\"title\":{\"type\":\"stri"
    "ng\",\"description\":\"A short filter title (e.g. for display in a "
    "selection list)\"},\"filter\":{\"type\":\"string\",\"description\":\"The RDB "
    "filter string to apply (e.g. when reading points or index), details "
    "see documentation of function "
    "select()\"},\"activated\":{\"type\":\"boolean\",\"description\":\"Apply ('true')"
    " or ignore ('false') this "
    "filter\"},\"description\":{\"type\":\"string\",\"description\":\"A brief "
    "description of the filter (e.g. for display in a tooltip)\"}},\"type\":\"o"
    "bject\",\"required\":[\"activated\",\"title\",\"description\",\"filter\"],\"descri"
    "ption\":\"Point filter definition\"},\"type\":\"array\",\"description\":\"List "
    "of point filters\"},\"activated\":{\"type\":\"boolean\",\"description\":\"Apply "
    "('true') or ignore ('false') all "
    "filters\"}},\"required\":[\"activated\",\"filters\"],\"description\":\"Point "
    "filters applied in addition to the application-defined "
    "filters\",\"title\":\"Stored filters\",\"$schema\":\"http://json-schema.org/dr"
    "aft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"filters\":[{\"title\":\"Ignore uncertain points from MTA "
    "resolution\",\"filter\":\"riegl.mta_uncertain_point == "
    "0\",\"activated\":false,\"description\":\"Ignore points with uncertain MTA "
    "zone assignment\"},{\"title\":\"Ignore points below dynamic trigger "
    "level\",\"filter\":\"riegl.dyntrig_uncertain_point == "
    "0\",\"activated\":false,\"description\":\"Ignore points with an echo signal "
    "amplitude below the dynamic trigger\"},{\"title\":\"Ignore points outside "
    "outer AABB\",\"filter\":\"riegl.point_outside_aabb_bocs == "
    "0\",\"activated\":false,\"description\":\"Ignore points that are outside the"
    " outer AABB in BOCS\"},{\"title\":\"Ignore points inside inner "
    "AABB\",\"filter\":\"riegl.point_inside_aabb_bocs == "
    "0\",\"activated\":false,\"description\":\"Ignore points that are inside the "
    "inner AABB in BOCS\"}],\"activated\":true}"
};

// Details of major system components like lidar sensors, cameras and navigation devices
const MetaDataItemInfo RDB_RIEGL_SYSTEM_DESCRIPTION = {
    /* name        */ "riegl.system_description",
    /* title       */ "System Description",
    /* description */ "Details of major system components like lidar sensors, cameras and navigation devices",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"version\":{\"type\":\"string\",\"description\":\"Document "
    "format version\"},\"author\":{\"type\":\"string\",\"description\":\"Name of the "
    "author that created the "
    "document\"},\"system\":{\"type\":\"object\",\"description\":\"The actual system "
    "description, details see documentation of RIEGL System Description\"},\""
    "$class\":{\"type\":\"string\",\"enum\":[\"Document\"],\"description\":\"Object "
    "class name\"},\"timestamp\":{\"type\":\"string\",\"description\":\"Date and time"
    " of creation (e.g. 2019-06-19T13:32:10+02:00)\"}},\"required\":[\"$class\","
    "\"version\",\"author\",\"timestamp\",\"system\"],\"description\":\"Details of "
    "major system components like lidar sensors, cameras and navigation "
    "devices\",\"title\":\"System Description\",\"$schema\":\"http://json-schema.or"
    "g/draft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"version\":\"1.2.1\",\"author\":\"RIEGL LMS GmbH, "
    "Austria\",\"system\":{\"details\":\"see documentation of RIEGL System Descri"
    "ption\"},\"$class\":\"Document\",\"timestamp\":\"2022-09-30T11:56:26+00:00\"}"
};

// Conversion of background radiation raw values to temperatures in °C
const MetaDataItemInfo RDB_RIEGL_TEMPERATURE_CALCULATION = {
    /* name        */ "riegl.temperature_calculation",
    /* title       */ "Temperature Calculation Table",
    /* description */ "Conversion of background radiation raw values to temperatures in °C",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"InGaAs_Si_Difference\":{\"$ref\":\"#/definitions/conversio"
    "n_table\",\"description\":\"Conversion table for InGaAs - Si difference\"},"
    "\"InGaAs\":{\"$ref\":\"#/definitions/conversion_table\",\"description\":\"Conve"
    "rsion table for InGaAs channel\"},\"Si\":{\"$ref\":\"#/definitions/conversio"
    "n_table\",\"description\":\"Conversion table for Si channel\"}},\"definition"
    "s\":{\"conversion_table\":{\"properties\":{\"value\":{\"items\":{\"type\":\"number"
    "\"},\"description\":\"LSB [1]\",\"type\":\"array\"},\"temperature\":{\"items\":{\"ty"
    "pe\":\"number\"},\"description\":\"Temperature [\\u00b0C]\",\"type\":\"array\"}},\""
    "required\":[\"value\",\"temperature\"],\"type\":\"object\"}},\"description\":\"Con"
    "version of background radiation raw values to temperatures in "
    "\\u00b0C\",\"title\":\"Temperature Calculation Table\",\"$schema\":\"http://jso"
    "n-schema.org/draft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"InGaAs_Si_Difference\":{\"value\":[1000.0,1100.090029602954,1200.044251"
    "83874,1300.1342814416948,1400.0885036774805,1500.0427259132668,1600.13"
    "27555162209,1700.0869777520065,1800.0411999877924],\"temperature\":[1749"
    ".977111117893,1749.977111117893,1749.977111117893,1749.977111117893,17"
    "49.977111117893,1749.977111117893,1744.7813348796044,1681.997131260109"
    "2,1622.3944822534868]},\"InGaAs\":{\"value\":[0.0,64.00097659230323,128.00"
    "19531846065,192.0029297769097,256.0039063692129,320.00488296151616,384"
    ".0058595538194,448.0068361461226,512.0078127384259],\"temperature\":[307"
    ".22196722535614,309.1153478247277,311.1188086915047,313.10025350480055"
    ",315.2137946389828,317.2172555057597,319.2207163725366,321.20216118583"
    "25,323.3157023200148]},\"Si\":{\"value\":[0.0,64.00097659230323,128.001953"
    "1846065,192.0029297769097,256.0039063692129,320.00488296151616,384.005"
    "8595538194,448.0068361461226,512.0078127384259],\"temperature\":[546.300"
    "048828125,548.8164051212026,551.3143938500972,554.0144257850053,556.60"
    "4252334815,559.2124464488079,561.8022729986177,564.4104671126105,567.0"
    "002936624203]}}"
};

// Base of timestamps (epoch)
const MetaDataItemInfo RDB_RIEGL_TIME_BASE = {
    /* name        */ "riegl.time_base",
    /* title       */ "Time Base",
    /* description */ "Base of timestamps (epoch)",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"epoch\":{\"type\":\"string\",\"description\":\"Date and time "
    "of timestamp '0' as proposed by RFC 3339 (e.g. 2015-10-27T00:00:00+01:"
    "00).\"},\"system\":{\"type\":\"string\",\"enum\":[\"unknown\",\"UTC\",\"GPS\"],\"descr"
    "iption\":\"Time system (time standard)\"},\"source\":{\"type\":\"string\",\"enum"
    "\":[\"unknown\",\"RTC\",\"GNSS\"],\"description\":\"Timestamp "
    "source\"}},\"required\":[\"epoch\",\"source\"],\"description\":\"Base of "
    "timestamps (epoch)\",\"title\":\"Time Base\",\"$schema\":\"http://json-schema."
    "org/draft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"epoch\":\"2015-10-27T00:00:00+00:00\",\"system\":\"UTC\",\"source\":\"GNSS\"}"
};

// Details about position+orientation files
const MetaDataItemInfo RDB_RIEGL_TRAJECTORY_INFO = {
    /* name        */ "riegl.trajectory_info",
    /* title       */ "Trajectory Information",
    /* description */ "Details about position+orientation files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"time_interval\":{\"properties\":{\"std_dev\":{\"type\":\"numbe"
    "r\",\"description\":\"Standard deviation of intervals "
    "[s]\"},\"minimum\":{\"type\":\"number\",\"description\":\"Minimum time interval "
    "[s]\"},\"average\":{\"type\":\"number\",\"description\":\"Average time interval "
    "[s]\"},\"maximum\":{\"type\":\"number\",\"description\":\"Maximum time interval "
    "[s]\"}},\"type\":\"object\",\"required\":[\"minimum\",\"average\",\"maximum\",\"std_"
    "dev\"],\"description\":\"Time interval "
    "statistics\"},\"project\":{\"type\":\"string\",\"description\":\"Project "
    "name\"},\"software\":{\"type\":\"string\",\"description\":\"Software that "
    "calculated the trajectory (this may be the same or different software "
    "than the one that created the "
    "file)\"},\"device\":{\"type\":\"string\",\"description\":\"Navigation device, "
    "e.g. name/type/serial\"},\"field_of_application\":{\"type\":\"string\",\"enum\""
    ":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"MLS\",\"ULS\",\"ALS\",\"BLS\",\"ILS\"],\"descript"
    "ion\":\"Field of "
    "application\"},\"company\":{\"type\":\"string\",\"description\":\"Company "
    "name\"},\"settings\":{\"type\":\"string\",\"description\":\"Settings used to "
    "calculate the trajectory (descriptive "
    "text)\"},\"location\":{\"type\":\"string\",\"description\":\"Project location, "
    "e.g. city/state/country\"},\"navigation_frame\":{\"type\":\"string\",\"enum\":["
    "\"unknown\",\"NED\",\"ENU\"],\"description\":\"Navigation frame (NED: "
    "North-East-Down, ENU: East-North-Up)\"}},\"required\":[\"time_interval\",\"n"
    "avigation_frame\"],\"description\":\"Details about position+orientation "
    "files\",\"title\":\"Trajectory Information\",\"$schema\":\"http://json-schema."
    "org/draft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"time_interval\":{\"std_dev\":5.51e-07,\"minimum\":0.00500032,\"average\":0."
    "00500053,\"maximum\":0.005004883},\"project\":\"Campaign "
    "3\",\"software\":\"Navigation Software XYZ\",\"device\":\"IMU Model 12/1, "
    "Serial# 12345\",\"field_of_application\":\"MLS\",\"company\":\"RIEGL "
    "LMS\",\"settings\":\"default\",\"location\":\"Horn\",\"navigation_frame\":\"NED\"}"
};

// Trigger-Timestamping-Unit/IP configuration
const MetaDataItemInfo RDB_RIEGL_TTIP_CONFIGURATION = {
    /* name        */ "riegl.ttip_configuration",
    /* title       */ "TTIP Configuration",
    /* description */ "Trigger-Timestamping-Unit/IP configuration",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"input_usage\":{\"minimum\":0,\"type\":\"integer\",\"descriptio"
    "n\":\"0 .. deactivated, 1 .. just detecting and timestamping\"},\"ext_chan"
    "nel\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"ID of channel used "
    "as external trigger input, 32 indicates none\"},\"ext_bitmask\":{\"minimum"
    "\":0,\"type\":\"integer\",\"description\":\"defines which of the internal "
    "pulse generators are to be started\"},\"ttip_version\":{\"minimum\":0,\"type"
    "\":\"integer\",\"description\":\"following main.sub.ss.sss\"},\"dmi_max_time\":"
    "{\"minimum\":0,\"type\":\"integer\",\"description\":\"dmi, maximum time "
    "interval between trigger events [0.1 msec]\"},\"out_delay\":{\"minimum\":0,"
    "\"type\":\"integer\",\"description\":\"output pulse initial delay after start"
    " [0.1 msec]\"},\"dmi_min_time\":{\"minimum\":0,\"type\":\"integer\",\"descriptio"
    "n\":\"dmi, minimum time interval between trigger events [0.1 msec]\"},\"in"
    "_min_duration\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"input "
    "signals with smaller pulse durations are ignored [0.1 msec]\"},\"out_num"
    "_pulses\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"number of output"
    " pulses to be generated, 0 .. infinite\"},\"out_polarity\":{\"minimum\":0,\""
    "type\":\"integer\",\"description\":\"0 .. positive edge, 1 .. negative "
    "edge\"},\"output_descr\":{\"type\":\"string\",\"description\":\"descriptive "
    "string\"},\"input_descr\":{\"type\":\"string\",\"description\":\"descriptive str"
    "ing\"},\"out_duration\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"outp"
    "ut pulse duration [0.1 msec]\"},\"ext_subdivider\":{\"minimum\":0,\"type\":\"i"
    "nteger\",\"description\":\"reduces the frequency, default "
    "1\"},\"ext_delay\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"external "
    "trigger, time delay [0.1 "
    "msec]\"},\"in_polarity\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"0 "
    ".. positive edge, 1 .. negative "
    "edge\"},\"dmi_incr\":{\"type\":\"integer\",\"description\":\"dmi, increment in t"
    "icks\"},\"in_max_delay\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"max"
    "imum delay to output pulse before fake event is generated [0.1 msec], "
    "zero indicates that no fake events are generated\"},\"ext_signal\":{\"mini"
    "mum\":0,\"type\":\"integer\",\"description\":\"0 .. use input signal, 1 .. use"
    " output signal of "
    "channel\"},\"channel\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"ID of"
    " input/output "
    "channel\"},\"dmi_dist_per_tick\":{\"type\":\"number\",\"description\":\"dmi, "
    "distance per tick, just informative [m]\"},\"out_interval\":{\"minimum\":0,"
    "\"type\":\"integer\",\"description\":\"output pulse interval [0.1 msec]\"},\"in"
    "_max_duration\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"stops "
    "measurement of pulse duration of input signal [0.1 msec]\"},\"num_channe"
    "l\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"number of input/output"
    " channels\"},\"output_usage\":{\"minimum\":0,\"type\":\"integer\",\"description\""
    ":\"0 .. no output, 1 .. output derived from internal clock, 2 .. output"
    " derived from dmi, 3 .. output derived from external signal, 4 .. "
    "output static low, 5 .. output static high\"}},\"required\":[\"ttip_versio"
    "n\",\"num_channel\",\"ext_channel\",\"ext_signal\",\"ext_delay\",\"ext_subdivide"
    "r\",\"ext_bitmask\",\"dmi_incr\",\"dmi_min_time\",\"dmi_max_time\",\"dmi_dist_pe"
    "r_tick\",\"channel\",\"output_descr\",\"input_descr\",\"output_usage\",\"input_u"
    "sage\",\"out_polarity\",\"out_duration\",\"out_interval\",\"out_delay\",\"out_nu"
    "m_pulses\",\"in_polarity\",\"in_min_duration\",\"in_max_duration\",\"in_max_de"
    "lay\"],\"description\":\"Trigger-Timestamping-Unit/IP "
    "configuration\",\"title\":\"TTIP Configuration\",\"$schema\":\"http://json-sch"
    "ema.org/draft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"input_usage\":1,\"ext_channel\":32,\"ext_bitmask\":0,\"ttip_version\":1,\"dm"
    "i_max_time\":0,\"out_delay\":0,\"dmi_min_time\":0,\"in_min_duration\":0,\"out_"
    "num_pulses\":1,\"out_polarity\":0,\"output_descr\":\"Port 1 - "
    "Trigger\",\"input_descr\":\"Port 1 - Exposure\",\"out_duration\":300,\"ext_sub"
    "divider\":1,\"ext_delay\":0,\"in_polarity\":0,\"dmi_incr\":0,\"in_max_delay\":9"
    "990,\"ext_signal\":0,\"channel\":0,\"dmi_dist_per_tick\":0.0,\"out_interval\":"
    "10000,\"in_max_duration\":10000,\"num_channel\":9,\"output_usage\":1}"
};

// Details about vertex file
const MetaDataItemInfo RDB_RIEGL_VERTEX_INFO = {
    /* name        */ "riegl.vertex_info",
    /* title       */ "Vertex Information",
    /* description */ "Details about vertex file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Vertex Information\",\"description\":\"Details "
    "about vertex file\",\"properties\":{\"vertex_file\":{\"properties\":{\"file_ex"
    "tension\":{\"type\":\"string\",\"description\":\"Vertex file extension, "
    "without the leading "
    "dot\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC 4122)\"}},\"required\":[\"file_extension\"],\"type\":\""
    "object\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"vertex_file\":{\"file_extension\":\"vtx\",\"file_uuid\":\"51534d95-d71f-4f36"
    "-ae1a-3e63a21fd1c7\"}}"
};

// Details about the voxels contained in the file
const MetaDataItemInfo RDB_RIEGL_VOXEL_INFO = {
    /* name        */ "riegl.voxel_info",
    /* title       */ "Voxel Information",
    /* description */ "Details about the voxels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"oneOf\":[{\"properties\":{\"voxel_type\":{\"$ref\":\"#/definitions/voxel_typ"
    "e\"},\"shape_thresholds\":{\"$ref\":\"#/definitions/shape_thresholds\"},\"size"
    "\":{\"oneOf\":[{\"$ref\":\"#/definitions/voxel_size\"},{\"$ref\":\"#/definitions"
    "/voxel_size_cubic\"}],\"description\":\"Size of voxels in file coordinate "
    "system.\"},\"voxel_origin\":{\"$ref\":\"#/definitions/voxel_origin_enum\"}},\""
    "required\":[\"size\",\"voxel_origin\",\"voxel_type\"],\"additionalProperties\":"
    "false},{\"properties\":{\"voxel_type\":{\"$ref\":\"#/definitions/voxel_type\"}"
    ",\"size\":{\"$ref\":\"#/definitions/voxel_size\",\"description\":\"Size of "
    "voxels in file coordinate system.\"},\"voxel_origin\":{\"oneOf\":[{\"$ref\":\""
    "#/definitions/voxel_origin_enum\"},{\"$ref\":\"#/definitions/voxel_origin_"
    "point\",\"description\":\"The base point of the voxel grid. Used together "
    "with <tt>voxel_size</tt> and <tt>voxel_index</tt> to compute actual "
    "point coordinates.\"}]},\"shape_thresholds\":{\"$ref\":\"#/definitions/shape"
    "_thresholds\"},\"size_llcs\":{\"$ref\":\"#/definitions/voxel_size\",\"descript"
    "ion\":\"Size of voxels in a locally levelled cartesian coordinate system"
    " (xyz). This is only used for voxels based on a map projection.\"},\"ref"
    "erence_point\":{\"items\":{\"minimum\":-180,\"maximum\":180,\"type\":\"number\"},"
    "\"minItems\":2,\"type\":\"array\",\"maxItems\":2,\"description\":\"Point in WGS84"
    " geodetic decimal degree (EPSG:4326) that was used to compute the "
    "projection distortion parameters. The coefficient order is latitude, "
    "longitude. Only voxels with corresponding geo_tag, voxel_size and "
    "reference_point can be reliably processed together. This entry is "
    "available for voxel files in projected CRS only.\"}},\"required\":[\"refer"
    "ence_point\",\"size_llcs\",\"size\",\"voxel_origin\",\"voxel_type\"],\"additiona"
    "lProperties\":false}],\"definitions\":{\"voxel_origin_point\":{\"items\":{\"ty"
    "pe\":\"number\"},\"minItems\":3,\"type\":\"array\",\"maxItems\":3,\"description\":\""
    "Origin point for all voxel indices in voxel CRS.\"},\"voxel_size_cubic\":"
    "{\"$ref\":\"#/definitions/edge_length\",\"type\":\"number\"},\"edge_length\":{\"t"
    "ype\":\"number\",\"exclusiveMinimum\":true,\"minimum\":0,\"description\":\"Lengt"
    "h of voxel edge [m].\"},\"voxel_type\":{\"default\":\"centroid\",\"enum\":[\"cen"
    "ter\",\"centroid\",\"index\"],\"description\":\"Whether a point in a voxel "
    "represents its center or its centroid. If type is <tt>index</tt> there"
    " is no point but only an integer voxel index.\"},\"shape_thresholds\":{\"t"
    "ype\":\"object\",\"properties\":{\"plane\":{\"exclusiveMinimum\":true,\"descript"
    "ion\":\"If the smallest eigenvalue is smaller than the median eigenvalue"
    " * plane_threshold, the voxel is considered a plane.\",\"exclusiveMaximu"
    "m\":true,\"minimum\":0,\"maximum\":1,\"type\":\"number\"},\"line\":{\"type\":\"numbe"
    "r\",\"exclusiveMinimum\":true,\"minimum\":1,\"description\":\"If the biggest "
    "eigenvalue is bigger than the median eigenvalue * line_threshold, the "
    "voxel is considered a "
    "line.\"}},\"required\":[\"plane\",\"line\"],\"description\":\"Thresholds used to"
    " compute the voxel's shape_id value.\"},\"voxel_origin_enum\":{\"default\":"
    "\"corner\",\"enum\":[\"center\",\"corner\"],\"description\":\"Defines whether the"
    " voxel's center or a corner is placed on CRS origin <tt>(0/0/0)</tt>.\""
    "},\"voxel_size\":{\"items\":{\"$ref\":\"#/definitions/edge_length\"},\"minItems"
    "\":3,\"type\":\"array\",\"maxItems\":3,\"description\":\"Size of "
    "voxels.\"}},\"description\":\"Details about the voxels contained in the "
    "file\",\"title\":\"Voxel Information\",\"$schema\":\"http://json-schema.org/dr"
    "aft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"voxel_type\":\"centroid\",\"size\":[0.5971642834779395,0.5971642834779395"
    ",0.5143705304787237],\"voxel_origin\":\"corner\",\"shape_thresholds\":{\"plan"
    "e\":0.16,\"line\":6},\"size_llcs\":[0.5156575252891171,0.5130835356683303,0"
    ".5143705304787237],\"reference_point\":[48,16]}"
};

// Settings for waveform averaging
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS = {
    /* name        */ "riegl.waveform_averaging_settings",
    /* title       */ "Waveform Averaging Settings",
    /* description */ "Settings for waveform averaging",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"trim\":{\"minimum\":0,\"description\":\"Percentage for "
    "robust averaging.\",\"default\":0,\"maximum\":0.5,\"type\":\"number\"},\"num_sho"
    "ts\":{\"minimum\":1,\"description\":\"Number of consecutive shots to be used"
    " for averaging.\",\"type\":\"integer\"},\"mta_zone\":{\"minimum\":1,\"descriptio"
    "n\":\"Fixed MTA zone for averaging.\",\"type\":\"integer\"}},\"required\":[\"num"
    "_shots\",\"mta_zone\"],\"description\":\"Settings for waveform "
    "averaging\",\"title\":\"Waveform Averaging Settings\",\"$schema\":\"http://jso"
    "n-schema.org/draft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"trim\":0.05,\"num_shots\":7,\"mta_zone\":1}"
};

// Details about waveform files
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_INFO = {
    /* name        */ "riegl.waveform_info",
    /* title       */ "Waveform Information",
    /* description */ "Details about waveform files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"ra"
    "nge_offset_waveform_samples_m\":{\"type\":\"number\",\"description\":\"Calibra"
    "ted device specific range offset for waveform samples in meters.\"},\"sa"
    "mple_data_files\":{\"items\":{\"properties\":{\"laser_wavelength\":{\"minimum\""
    ":0,\"type\":\"number\",\"exclusiveMinimum\":false,\"description\":\"Laser "
    "wavelength in meters (0 = unknown)\"},\"sample_bits\":{\"exclusiveMinimum\""
    ":false,\"description\":\"Bitwidth of samples (e.g. 10 bit, 12 bit)\",\"excl"
    "usiveMaximum\":false,\"minimum\":0,\"maximum\":32,\"type\":\"integer\"},\"delta_"
    "st\":{\"type\":\"number\",\"description\":\"reserved\"},\"sample_interval\":{\"min"
    "imum\":0,\"type\":\"number\",\"exclusiveMinimum\":false,\"description\":\"Sampli"
    "ng interval in "
    "seconds\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's "
    "Universally Unique Identifier (RFC "
    "4122)\"},\"channel\":{\"exclusiveMinimum\":false,\"description\":\"Sample "
    "block channel number (255 = invalid)\",\"exclusiveMaximum\":false,\"minimu"
    "m\":0,\"maximum\":255,\"type\":\"integer\"},\"file_extension\":{\"type\":\"string\""
    ",\"description\":\"Sample data file extension, without the leading "
    "dot\"},\"channel_name\":{\"type\":\"string\",\"description\":\"Sample block "
    "channel name\"}},\"required\":[\"channel\",\"channel_name\",\"sample_interval\""
    ",\"sample_bits\",\"laser_wavelength\",\"delta_st\",\"file_extension\"],\"type\":"
    "\"object\"},\"type\":\"array\"},\"range_offset_m\":{\"type\":\"number\",\"descripti"
    "on\":\"Calibrated device specific range offset for waveform analysis by "
    "system response fitting in meters.\"},\"sample_block_file\":{\"properties\""
    ":{\"file_extension\":{\"type\":\"string\",\"description\":\"Sample block file "
    "extension, without the leading "
    "dot\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC 4122)\"}},\"required\":[\"file_extension\"],\"type\":\""
    "object\"}},\"description\":\"Details about waveform "
    "files\",\"title\":\"Waveform Information\",\"required\":[\"sample_block_file\","
    "\"sample_data_files\"],\"type\":\"object\"}"
    ,
    /* example: */
    "{\"sample_data_files\":[{\"laser_wavelength\":0,\"sample_bits\":12,\"delta_st"
    "\":0,\"sample_interval\":1.00503e-09,\"file_uuid\":\"da084413-e3e8-4655-a122"
    "-071de8490d8e\",\"channel\":0,\"file_extension\":\"sp0\",\"channel_name\":\"high"
    "_power\"},{\"laser_wavelength\":0,\"sample_bits\":12,\"delta_st\":0,\"sample_i"
    "nterval\":1.00503e-09,\"file_uuid\":\"93585b5e-5ea9-43a1-947b-e7ba3be642d2"
    "\",\"channel\":1,\"file_extension\":\"sp1\",\"channel_name\":\"low_power\"},{\"las"
    "er_wavelength\":0,\"sample_bits\":12,\"delta_st\":0,\"sample_interval\":1.005"
    "03e-09,\"file_uuid\":\"9d2298c4-1036-464f-b5cb-1cf8e517f3a0\",\"channel\":5,"
    "\"file_extension\":\"sp5\",\"channel_name\":\"wwf\"}],\"range_offset_m\":3.1415,"
    "\"sample_block_file\":{\"file_extension\":\"sbx\",\"file_uuid\":\"93a03615-66c0"
    "-4bea-8ff8-c577378fe660\"},\"range_offset_waveform_samples_m \":7.283}"
};

// Scanner settings for waveform output
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_SETTINGS = {
    /* name        */ "riegl.waveform_settings",
    /* title       */ "Waveform Settings",
    /* description */ "Scanner settings for waveform output",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"array\",\"items\":{\"properties\":{\"logic_expression\":{\"type\":\"str"
    "ing\",\"description\":\"Logic expression of smart waveforms "
    "filter\"},\"pass_dev_greater\":{\"type\":\"integer\",\"description\":\"Threshold"
    " for deviation greater than "
    "[1]\"},\"pass_ampl_greater\":{\"type\":\"number\",\"description\":\"Threshold "
    "for amplitude greater than "
    "[dB]\"},\"smart_enabled\":{\"type\":\"boolean\",\"description\":\"Smart waveform"
    " output "
    "enabled\"},\"pass_rng_less\":{\"type\":\"number\",\"description\":\"Threshold "
    "for range less than "
    "[m]\"},\"pass_dev_less\":{\"type\":\"integer\",\"description\":\"Threshold for "
    "deviation less than "
    "[1]\"},\"pass_ampl_less\":{\"type\":\"number\",\"description\":\"Threshold for "
    "amplitude less than "
    "[dB]\"},\"enabled\":{\"type\":\"boolean\",\"description\":\"Waveform output "
    "enabled\"},\"pass_rng_greater\":{\"type\":\"number\",\"description\":\"Threshold"
    " for range greater than "
    "[m]\"},\"sbl_name\":{\"type\":\"string\",\"description\":\"Name of sample block,"
    " e.g.: wfm, "
    "wwf\"},\"channel_idx_mask\":{\"type\":\"integer\",\"description\":\"Bit mask for"
    " channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = "
    "Bit1, ...\"}},\"required\":[\"sbl_name\",\"enabled\",\"channel_idx_mask\"],\"typ"
    "e\":\"object\"},\"title\":\"Waveform Settings\",\"description\":\"Scanner "
    "settings for waveform "
    "output\",\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "[{\"pass_ampl_greater\":1.0,\"smart_enabled\":true,\"pass_rng_less\":13.11,\""
    "pass_ampl_less\":5.0,\"enabled\":true,\"pass_rng_greater\":9.27,\"sbl_name\":"
    "\"wfm\",\"channel_idx_mask\":11},{\"enabled\":false,\"channel_idx_mask\":32,\"s"
    "bl_name\":\"wwf\"}]"
};

// Window analysis data estimated from scandata and resulting filter parameters
const MetaDataItemInfo RDB_RIEGL_WINDOW_ANALYSIS = {
    /* name        */ "riegl.window_analysis",
    /* title       */ "Window Analysis",
    /* description */ "Window analysis data estimated from scandata and resulting filter parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"settings\":{\"properties\":{\"amplitude\":{\"properties\":{\"s"
    "igma_factor\":{\"type\":\"number\"},\"additive_value\":{\"type\":\"number\"}},\"re"
    "quired\":[\"sigma_factor\",\"additive_value\"],\"type\":\"object\"},\"range\":{\"p"
    "roperties\":{\"sigma_factor\":{\"type\":\"number\"},\"additive_value\":{\"type\":"
    "\"number\"}},\"required\":[\"sigma_factor\",\"additive_value\"],\"type\":\"object"
    "\"}},\"required\":[\"range\",\"amplitude\"],\"type\":\"object\"},\"filter\":{\"prope"
    "rties\":{\"angle\":{\"items\":{\"type\":\"number\"},\"description\":\"[deg]\",\"type"
    "\":\"array\"},\"range_min\":{\"items\":{\"type\":\"number\"},\"description\":\"[m]\","
    "\"type\":\"array\"},\"range_max\":{\"items\":{\"type\":\"number\"},\"description\":\""
    "[m]\",\"type\":\"array\"},\"amplitude_max\":{\"items\":{\"type\":\"number\"},\"descr"
    "iption\":\"[dB]\",\"type\":\"array\"}},\"required\":[\"angle\",\"range_min\",\"range"
    "_max\",\"amplitude_max\"],\"type\":\"object\"},\"result\":{\"properties\":{\"angle"
    "\":{\"items\":{\"type\":\"number\"},\"description\":\"[deg]\",\"type\":\"array\"},\"am"
    "plitude_sigma\":{\"items\":{\"type\":\"number\"},\"description\":\"[dB]\",\"type\":"
    "\"array\"},\"amplitude_mean\":{\"items\":{\"type\":\"number\"},\"description\":\"[d"
    "B]\",\"type\":\"array\"},\"range_sigma\":{\"items\":{\"type\":\"number\"},\"descript"
    "ion\":\"[m]\",\"type\":\"array\"},\"timestamp\":{\"items\":{\"type\":\"number\"},\"des"
    "cription\":\"[s]\",\"type\":\"array\"},\"range_mean\":{\"items\":{\"type\":\"number\""
    "},\"description\":\"[m]\",\"type\":\"array\"},\"amplitude_offset\":{\"items\":{\"ty"
    "pe\":\"number\"},\"description\":\"[dB]\",\"type\":\"array\"}},\"required\":[\"angle"
    "\",\"range_mean\",\"range_sigma\",\"amplitude_mean\",\"amplitude_sigma\",\"ampli"
    "tude_offset\"],\"type\":\"object\"}},\"required\":[\"result\",\"filter\",\"setting"
    "s\"],\"description\":\"Window analysis data estimated from scandata and "
    "resulting filter parameters\",\"title\":\"Window Analysis\",\"$schema\":\"http"
    "://json-schema.org/draft-04/schema#\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"settings\":{\"amplitude\":{\"sigma_factor\":4,\"additive_value\":1.0},\"rang"
    "e\":{\"sigma_factor\":8,\"additive_value\":0.1}},\"filter\":{\"angle\":[14.9,15"
    ".0,15.1,15.2,15.3,15.4,15.5,15.6,15.7,15.8,15.9],\"range_min\":[-0.208,-"
    "0.21,-0.212,-0.214,-0.216,-0.218,-0.219,-0.221,-0.223,-0.225,-0.227],\""
    "range_max\":[0.424,0.425,0.426,0.427,0.428,0.428,0.429,0.43,0.431,0.431"
    ",0.432],\"amplitude_max\":[8.04,8.01,7.99,7.96,7.93,7.9,7.88,7.85,7.83,7"
    ".8,7.78]},\"result\":{\"angle\":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,1"
    "5.7,15.8,15.9],\"amplitude_sigma\":[0.4272844,0.4298479,0.4236816,0.4283"
    "583,0.4362353,0.4315141,0.4373984,0.4472798,0.4346001,0.4345487,0.4540"
    "681],\"amplitude_mean\":[5.347396,5.263155,5.224655,5.179926,5.097782,5."
    "116479,5.051756,4.983473,5.007885,5.002441,4.982],\"range_sigma\":[0.018"
    "69652,0.02151435,0.01747969,0.01918765,0.01945776,0.01934862,0.0195532"
    "9,0.02225589,0.02229977,0.01899122,0.02009433],\"timestamp\":[408.4441,4"
    "11.4443],\"range_mean\":[0.1105621,0.1079564,0.1087088,0.1067261,0.10545"
    "82,0.1090412,0.102871,0.1019044,0.1051523,0.1058445,0.1031261],\"amplit"
    "ude_offset\":[1.9,1.9]}}"
};

// Correction parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_WINDOW_ECHO_CORRECTION = {
    /* name        */ "riegl.window_echo_correction",
    /* title       */ "Window Echo Correction",
    /* description */ "Correction parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"amplitude\":{\"properties\":{\"minimum\":{\"minimum\":0.0,\"de"
    "scription\":\"Minimum amplitude in "
    "dB\",\"type\":\"number\"},\"maximum\":{\"minimum\":0.0,\"description\":\"Maximum "
    "amplitude in "
    "dB\",\"type\":\"number\"},\"entries\":{\"minimum\":1,\"description\":\"Number of "
    "amplitude entries\",\"type\":\"integer\"}},\"description\":\"Amplitude axis of"
    " correction table\",\"required\":[\"minimum\",\"maximum\",\"entries\"],\"type\":\""
    "object\"},\"range\":{\"properties\":{\"minimum\":{\"minimum\":-2.0,\"description"
    "\":\"Minimum range in m\",\"maximum\":2.0,\"type\":\"number\"},\"maximum\":{\"mini"
    "mum\":-2.0,\"description\":\"Maximum range in m\",\"maximum\":2.0,\"type\":\"num"
    "ber\"},\"entries\":{\"minimum\":1,\"description\":\"Number of range "
    "entries\",\"type\":\"integer\"}},\"description\":\"Range axis of correction ta"
    "ble\",\"required\":[\"minimum\",\"maximum\",\"entries\"],\"type\":\"object\"},\"slic"
    "es\":{\"items\":{\"properties\":{\"amplitude\":{\"description\":\"Window echo "
    "amplitude of slice in dB\",\"type\":\"number\"},\"table\":{\"items\":{\"items\":{"
    "\"items\":{\"type\":\"number\",\"description\":\"Table cell (item 0: amplitude "
    "in dB, 1: range in m, 2: flags)\"},\"minItems\":3,\"description\":\"Table "
    "column (= range "
    "axis)\",\"maxItems\":3,\"type\":\"array\"},\"minItems\":1,\"description\":\"Table "
    "row (= amplitude "
    "axis)\",\"type\":\"array\"},\"minItems\":1,\"description\":\"Correction table "
    "(dimension defined by the 'amplitude' and 'range' "
    "objects)\",\"type\":\"array\"}},\"description\":\"Window echo correction "
    "parameter slice\",\"required\":[\"amplitude\",\"table\"],\"type\":\"object\"},\"ty"
    "pe\":\"array\"}},\"required\":[\"amplitude\",\"range\",\"slices\"],\"description\":"
    "\"Correction parameters for window glass echoes\",\"title\":\"Window Echo C"
    "orrection\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":"
    "\"object\"}"
    ,
    /* example: */
    "{\"amplitude\":{\"minimum\":2,\"maximum\":20,\"entries\":128},\"range\":{\"minimu"
    "m\":-1.5060822940732335,\"maximum\":1.5060822940732335,\"entries\":128},\"sl"
    "ices\":[{\"amplitude\":1.5,\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]]"
    "},{\"amplitude\":2.0,\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]]}]}"
};

// Table of all meta data item details records
const MetaDataItemInfo* const RDB_META_DATA_ITEMS[] = {
    &RDB_RIEGL_ANGULAR_NOTCH_FILTER,
    &RDB_RIEGL_ATMOSPHERE,
    &RDB_RIEGL_BEAM_GEOMETRY,
    &RDB_RIEGL_CONTROL_OBJECT_CATALOG,
    &RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE,
    &RDB_RIEGL_DETECTION_PROBABILITY,
    &RDB_RIEGL_DEVICE,
    &RDB_RIEGL_DEVICE_GEOMETRY,
    &RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL,
    &RDB_RIEGL_DEVICE_OUTPUT_LIMITS,
    &RDB_RIEGL_DEVICES,
    &RDB_RIEGL_DYNTRIG,
    &RDB_RIEGL_ECHO_INFO,
    &RDB_RIEGL_EXPONENTIAL_DECOMPOSITION,
    &RDB_RIEGL_GAUSSIAN_DECOMPOSITION,
    &RDB_RIEGL_GEO_TAG,
    &RDB_RIEGL_GEOMETRIC_SCALE_FACTOR,
    &RDB_RIEGL_GEOREFERENCING_PARAMETERS,
    &RDB_RIEGL_ITEM_NAMES,
    &RDB_RIEGL_LICENSES,
    &RDB_RIEGL_MTA_SETTINGS,
    &RDB_RIEGL_NEAR_RANGE_CORRECTION,
    &RDB_RIEGL_NOISE_ESTIMATES,
    &RDB_RIEGL_NOTCH_FILTER,
    &RDB_RIEGL_PIXEL_INFO,
    &RDB_RIEGL_PLANE_PATCH_MATCHING,
    &RDB_RIEGL_PLANE_PATCH_STATISTICS,
    &RDB_RIEGL_PLANE_SLOPE_CLASS_INFO,
    &RDB_RIEGL_POINT_ATTRIBUTE_GROUPS,
    &RDB_RIEGL_POINTCLOUD_INFO,
    &RDB_RIEGL_POSE_ESTIMATION,
    &RDB_RIEGL_POSE_SENSORS,
    &RDB_RIEGL_PULSE_POSITION_MODULATION,
    &RDB_RIEGL_RANGE_STATISTICS,
    &RDB_RIEGL_RECEIVER_INTERNALS,
    &RDB_RIEGL_REFLECTANCE_CALCULATION,
    &RDB_RIEGL_REFLECTANCE_CORRECTION,
    &RDB_RIEGL_SCAN_PATTERN,
    &RDB_RIEGL_SHOT_INFO,
    &RDB_RIEGL_STORED_FILTERS,
    &RDB_RIEGL_SYSTEM_DESCRIPTION,
    &RDB_RIEGL_TEMPERATURE_CALCULATION,
    &RDB_RIEGL_TIME_BASE,
    &RDB_RIEGL_TRAJECTORY_INFO,
    &RDB_RIEGL_TTIP_CONFIGURATION,
    &RDB_RIEGL_VERTEX_INFO,
    &RDB_RIEGL_VOXEL_INFO,
    &RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS,
    &RDB_RIEGL_WAVEFORM_INFO,
    &RDB_RIEGL_WAVEFORM_SETTINGS,
    &RDB_RIEGL_WINDOW_ANALYSIS,
    &RDB_RIEGL_WINDOW_ECHO_CORRECTION
};
const std::size_t RDB_META_DATA_ITEM_COUNT(
    sizeof(RDB_META_DATA_ITEMS) / sizeof(RDB_META_DATA_ITEMS[0])
);
const std::vector<const MetaDataItemInfo*> RDB_META_DATA_ITEMS_VECTOR(
    RDB_META_DATA_ITEMS, RDB_META_DATA_ITEMS + RDB_META_DATA_ITEM_COUNT
);

}}} // namespace riegl::rdb::pointcloud

#endif // RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87
